export interface TextObject {
    /**
     * The formatting to use for this text object. Can be one of plain_textor mrkdwn.
     */
    type: 'plain_text' | 'mrkdwn';
    /**
     * The text for the block. This field accepts any of the standard text formatting markup when type is mrkdwn.
     */
    text: string;
    /**
     * Indicates whether emojis in a text field should be escaped into the colon emoji format. This field is only usable when type is plain_text.
     */
    emoji?: boolean;
    /**
     * When set to false (as is default) URLs will be auto-converted into links, conversation names will be link-ified, and certain mentions will be automatically parsed.
     * Using a value of true will skip any preprocessing of this nature, although you can still include manual parsing strings. This field is only usable when type is mrkdwn.
     */
    verbatim?: boolean;
}
export interface ConfirmationDialog {
    /**
     * A plain_text-only text object that defines the dialog's title. Maximum length for this field is 100 characters.
     */
    title: TextObject;
    /**
     * A text object that defines the explanatory text that appears in the confirm dialog. Maximum length for the text in this field is 300 characters.
     */
    text: TextObject;
    /**
     * A plain_text-only text object to define the text of the button that confirms the action. Maximum length for the text in this field is 30 characters.
     */
    confirm: TextObject;
    /**
     * A plain_text-only text object to define the text of the button that cancels the action. Maximum length for the text in this field is 30 characters.
     */
    deny: TextObject;
}
export interface Option {
    /**
     * A plain_text only text object that defines the text shown in the option on the menu. Maximum length for the text in this field is 75 characters.
     */
    text: TextObject;
    /**
     * 	The string value that will be passed to your app when this option is chosen. Maximum length for this field is 75 characters.
     */
    value: string;
    /**
     * A plain_text only text object that defines a line of descriptive text shown below the text field beside the radio button. Maximum length for the text object within this field is 75 characters.
     */
    description?: TextObject;
    /**
     * A URL to load in the user's browser when the option is clicked. The url attribute is only available in overflow menus. Maximum length for this field is 3000 characters. If you're using url, you'll still receive an interaction payload and will need to send an acknowledgement response.
     */
    url?: string;
}
export interface OptionGroup {
    /**
     * A plain_text only text object that defines the label shown above this group of options. Maximum length for the text in this field is 75 characters.
     */
    label: TextObject;
    /**
     * 	An array of option objects that belong to this specific group. Maximum of 100 items.
     */
    options: Option[];
}
//# sourceMappingURL=compositionObjects.d.ts.map