import { TextObject, ActionsBlock, ContextBlock, DividerBlock, ImageBlock, SectionBlock, HeaderBlock, InputBlock } from "../blockKit";
export interface objs_view_home_tab {
    /**
     * The type of view. Set to modal for modals and home for Home tabs.
     */
    type: string;
    /**
     * An array of blocks that defines the content of the view. Max of 100 blocks.
     */
    blocks: (ActionsBlock | ContextBlock | DividerBlock | ImageBlock | SectionBlock | HeaderBlock | InputBlock)[];
    /**
     * An optional string that will be sent to your app in view_submission and block_actions events. Max length of 3000 characters.
     */
    private_metadata?: string;
    /**
     * An identifier to recognize interactions and submissions of this particular view. Don't use this to store sensitive information (use private_metadata instead). Max length of 255 characters.
     */
    callback_id?: string;
    /**
     * A custom identifier that must be unique for all views on a per-team basis.
     */
    external_id?: string;
}
export interface objs_view_response extends objs_view_home_tab {
    id?: string;
    team_id?: string;
    state?: {
        values?: Record<string, any>;
    };
    hash?: string;
    root_view_id?: string;
    app_id?: string;
    bot_id?: string;
    previous_view_id?: string | null;
    app_installed_team_id?: string;
}
export interface objs_view_modal extends objs_view_home_tab {
    /**
     * The title that appears in the top-left of the modal. Must be a plain_text text element with a max length of 24 characters.
     */
    title: TextObject;
    /**
     * An optional plain_text element that defines the text displayed in the close button at the bottom-right of the view. Max length of 24 characters.
     */
    close?: TextObject;
    /**
     * An optional plain_text element that defines the text displayed in the submit button at the bottom-right of the view. submit is required when an input block is within the blocks array. Max length of 24 characters.
     */
    submit?: TextObject;
    /**
     * When set to true, clicking on the close button will clear all views in a modal and close it. Defaults to false.
     */
    clear_on_close?: boolean;
    /**
     * Indicates whether Slack will send your request URL a view_closed event when a user clicks the close button. Defaults to false.
     */
    notify_on_close?: boolean;
    /**
     * When set to true, disables the submit button until the user has completed one or more inputs. This property is for configuration modals.
     */
    submit_disabled?: boolean;
}
//# sourceMappingURL=objs_view.d.ts.map