import { Admin } from "../../types/admin";
/**
 * Set an existing guest user, admin user, or owner to be a regular user.
 * Documentation: https://api.slack.com/methods/admin.users.setRegular
 * @param options Request options.
 */
export declare function adminSetRegularUser<T = Admin.Users.SetRegular.Response.OK>(options: Admin.Users.SetRegular.Options.HandledApi): Promise<Admin.Users.SetRegular.Response.OK>;
/**
 * Set an existing guest, regular user, or admin user to be a workspace owner.
 * Documentation: https://api.slack.com/methods/admin.users.setOwner
 * @param options Request options.
 */
export declare function adminSetOwnerUser<T = Admin.Users.SetOwner.Response.OK>(options: Admin.Users.SetOwner.Options.HandledApi): Promise<Admin.Users.SetOwner.Response.OK>;
/**
 * Set an expiration for a guest user
 * Documentation: https://api.slack.com/methods/admin.users.setExpiration
 * @param options Request options.
 */
export declare function adminSetUserExpiration<T = Admin.Users.SetExpiration.Response.OK>(options: Admin.Users.SetExpiration.Options.HandledApi): Promise<Admin.Users.SetExpiration.Response.OK>;
/**
 * Set an existing guest, regular user, or owner to be an admin user.
 * Documentation: https://api.slack.com/methods/admin.users.setAdmin
 * @param options Request options.
 */
export declare function adminSetAdminUser<T = Admin.Users.SetAdmin.Response.OK>(options: Admin.Users.SetAdmin.Options.HandledApi): Promise<Admin.Users.SetAdmin.Response.OK>;
/**
 * Remove a user from a workspace.
 * Documentation: https://api.slack.com/methods/admin.users.remove
 * @param options Request options.
 */
export declare function adminRemoveUser<T = Admin.Users.RemoveUser.Response.OK>(options: Admin.Users.RemoveUser.Options.HandledApi): Promise<Admin.Users.RemoveUser.Response.OK>;
/**
 * List users on a workspace
 * Documentation: https://api.slack.com/methods/admin.users.list
 * @param options Request options.
 */
export declare function adminGetUsers<T = Admin.Users.GetUsers.Response.OK>(options: Admin.Users.GetUsers.Options.HandledApi): Promise<Admin.Users.GetUsers.Response.OK>;
/**
 * Invite a user to a workspace.
 * Documentation: https://api.slack.com/methods/admin.users.invite
 * @param options Request options.
 */
export declare function adminInviteUser<T = Admin.Users.InviteUser.Response.OK>(options: Admin.Users.InviteUser.Options.HandledApi): Promise<Admin.Users.InviteUser.Response.OK>;
/**
 * Add an Enterprise user to a workspace.
 * Documentation: https://api.slack.com/methods/admin.users.assign
 * @param options Request options.
 */
export declare function adminAssignUser<T = Admin.Users.AssignUser.Response.OK>(options: Admin.Users.AssignUser.Options.HandledApi): Promise<Admin.Users.AssignUser.Response.OK>;
//# sourceMappingURL=users.d.ts.map