import { adminSetRegularUser as adminSetRegularUserFn } from "../../raw-api/admin/users";
import { executeRequest } from "../../handled-api/common";
import { adminSetOwnerUser as adminSetOwnerUserFn } from "../../raw-api/admin/users";
import { adminSetUserExpiration as adminSetUserExpirationFn } from "../../raw-api/admin/users";
import { adminSetAdminUser as adminSetAdminUserFn } from "../../raw-api/admin/users";
import { adminRemoveUser as adminRemoveUserFn } from "../../raw-api/admin/users";
import { adminGetUsers as adminGetUsersFn } from "../../raw-api/admin/users";
import { adminInviteUser as adminInviteUserFn } from "../../raw-api/admin/users";
import { adminAssignUser as adminAssignUserFn } from "../../raw-api/admin/users";
/**
 * Set an existing guest user, admin user, or owner to be a regular user.
 * Documentation: https://api.slack.com/methods/admin.users.setRegular
 * @param options Request options.
 */
export function adminSetRegularUser(options) {
    return executeRequest(() => adminSetRegularUserFn(options), options.errorStrategy);
}
/**
 * Set an existing guest, regular user, or admin user to be a workspace owner.
 * Documentation: https://api.slack.com/methods/admin.users.setOwner
 * @param options Request options.
 */
export function adminSetOwnerUser(options) {
    return executeRequest(() => adminSetOwnerUserFn(options), options.errorStrategy);
}
/**
 * Set an expiration for a guest user
 * Documentation: https://api.slack.com/methods/admin.users.setExpiration
 * @param options Request options.
 */
export function adminSetUserExpiration(options) {
    return executeRequest(() => adminSetUserExpirationFn(options), options.errorStrategy);
}
/**
 * Set an existing guest, regular user, or owner to be an admin user.
 * Documentation: https://api.slack.com/methods/admin.users.setAdmin
 * @param options Request options.
 */
export function adminSetAdminUser(options) {
    return executeRequest(() => adminSetAdminUserFn(options), options.errorStrategy);
}
/**
 * Remove a user from a workspace.
 * Documentation: https://api.slack.com/methods/admin.users.remove
 * @param options Request options.
 */
export function adminRemoveUser(options) {
    return executeRequest(() => adminRemoveUserFn(options), options.errorStrategy);
}
/**
 * List users on a workspace
 * Documentation: https://api.slack.com/methods/admin.users.list
 * @param options Request options.
 */
export function adminGetUsers(options) {
    return executeRequest(() => adminGetUsersFn(options), options.errorStrategy);
}
/**
 * Invite a user to a workspace.
 * Documentation: https://api.slack.com/methods/admin.users.invite
 * @param options Request options.
 */
export function adminInviteUser(options) {
    return executeRequest(() => adminInviteUserFn(options), options.errorStrategy);
}
/**
 * Add an Enterprise user to a workspace.
 * Documentation: https://api.slack.com/methods/admin.users.assign
 * @param options Request options.
 */
export function adminAssignUser(options) {
    return executeRequest(() => adminAssignUserFn(options), options.errorStrategy);
}
