import { deleteChatMessage as deleteChatMessageFn } from "../raw-api/chat";
import { executeRequest } from "../handled-api/common";
import { deleteChatScheduledMessage as deleteChatScheduledMessageFn } from "../raw-api/chat";
import { getChatPermalink as getChatPermalinkFn } from "../raw-api/chat";
import { postChatMeMessage as postChatMeMessageFn } from "../raw-api/chat";
import { postChatEphemeralMessage as postChatEphemeralMessageFn } from "../raw-api/chat";
import { postChatMessage as postChatMessageFn } from "../raw-api/chat";
import { scheduleChatMessage as scheduleChatMessageFn } from "../raw-api/chat";
import { unfurlChatMessage as unfurlChatMessageFn } from "../raw-api/chat";
import { updateChatMessage as updateChatMessageFn } from "../raw-api/chat";
/**
 * Deletes a message.
 * Documentation: https://api.slack.com/methods/chat.delete
 * @param options Request options.
 */
export function deleteChatMessage(options) {
    return executeRequest(() => deleteChatMessageFn(options), options.errorStrategy);
}
/**
 * Deletes a pending scheduled message from the queue.
 * Documentation: https://api.slack.com/methods/chat.deleteScheduledMessage
 * @param options Request options.
 */
export function deleteChatScheduledMessage(options) {
    return executeRequest(() => deleteChatScheduledMessageFn(options), options.errorStrategy);
}
/**
 * Retrieve a permalink URL for a specific extant message
 * Documentation: https://api.slack.com/methods/chat.getPermalink
 * @param options Request options.
 */
export function getChatPermalink(options) {
    return executeRequest(() => getChatPermalinkFn(options), options.errorStrategy);
}
/**
 * Share a me message into a channel.
 * Documentation: https://api.slack.com/methods/chat.meMessage
 * @param options Request options.
 */
export function postChatMeMessage(options) {
    return executeRequest(() => postChatMeMessageFn(options), options.errorStrategy);
}
/**
 * Sends an ephemeral message to a user in a channel.
 * Documentation: https://api.slack.com/methods/chat.postEphemeral
 * @param options Request options.
 */
export function postChatEphemeralMessage(options) {
    return executeRequest(() => postChatEphemeralMessageFn(options), options.errorStrategy);
}
/**
 * Sends a message to a channel.
 * Documentation: https://api.slack.com/methods/chat.postMessage
 * @param options Request options.
 */
export function postChatMessage(options) {
    return executeRequest(() => postChatMessageFn(options), options.errorStrategy);
}
/**
 * Schedules a message to be sent to a channel.
 * Documentation: https://api.slack.com/methods/chat.scheduleMessage
 * @param options Request options.
 */
export function scheduleChatMessage(options) {
    return executeRequest(() => scheduleChatMessageFn(options), options.errorStrategy);
}
/**
 * Provide custom unfurl behavior for user-posted URLs
 * Documentation: https://api.slack.com/methods/chat.unfurl
 * @param options Request options.
 */
export function unfurlChatMessage(options) {
    return executeRequest(() => unfurlChatMessageFn(options), options.errorStrategy);
}
/**
 * Updates a message.
 * Documentation: https://api.slack.com/methods/chat.update
 * @param options Request options.
 */
export function updateChatMessage(options) {
    return executeRequest(() => updateChatMessageFn(options), options.errorStrategy);
}
