import { Conversation } from "../types/conversation";
/**
 * Archives a conversation.
 * Documentation: https://api.slack.com/methods/conversations.archive
 * @param options Request options.
 */
export declare function archiveConversation<T = Conversation.ArchiveConversation.Response.OK>(options: Conversation.ArchiveConversation.Options.HandledApi): Promise<Conversation.ArchiveConversation.Response.OK>;
/**
 * Closes a direct message or multi-person direct message.
 * Documentation: https://api.slack.com/methods/conversations.close
 * @param options Request options.
 */
export declare function closeConversation<T = Conversation.CloseConversation.Response.OK>(options: Conversation.CloseConversation.Options.HandledApi): Promise<Conversation.CloseConversation.Response.OK>;
/**
 * Initiates a public or private channel-based conversation
 * Documentation: https://api.slack.com/methods/conversations.create
 * @param options Request options.
 */
export declare function createConversation<T = Conversation.CreateConversation.Response.OK>(options: Conversation.CreateConversation.Options.HandledApi): Promise<Conversation.CreateConversation.Response.OK>;
/**
 * Fetches a conversation's history of messages and events.
 * Documentation: https://api.slack.com/methods/conversations.history
 * @param options Request options.
 */
export declare function getConversationHistory<T = Conversation.GetHistory.Response.OK>(options: Conversation.GetHistory.Options.HandledApi): Promise<Conversation.GetHistory.Response.OK>;
/**
 * Retrieve information about a conversation.
 * Documentation: https://api.slack.com/methods/conversations.info
 * @param options Request options.
 */
export declare function getConversationInfo<T = Conversation.GetInfo.Response.OK>(options: Conversation.GetInfo.Options.HandledApi): Promise<Conversation.GetInfo.Response.OK>;
/**
 * Invites users to a channel.
 * Documentation: https://api.slack.com/methods/conversations.invite
 * @param options Request options.
 */
export declare function inviteUserToConversation<T = Conversation.InviteUser.Response.OK>(options: Conversation.InviteUser.Options.HandledApi): Promise<Conversation.InviteUser.Response.OK>;
/**
 * Joins an existing conversation.
 * Documentation: https://api.slack.com/methods/conversations.join
 * @param options Request options.
 */
export declare function joinConversation<T = Conversation.JoinConversation.Response.OK>(options: Conversation.JoinConversation.Options.HandledApi): Promise<Conversation.JoinConversation.Response.OK>;
/**
 * Removes a user from a conversation.
 * Documentation: https://api.slack.com/methods/conversations.kick
 * @param options Request options.
 */
export declare function kickUserFromConversation<T = Conversation.KickUser.Response.OK>(options: Conversation.KickUser.Options.HandledApi): Promise<Conversation.KickUser.Response.OK>;
/**
 * Leaves a conversation.
 * Documentation: https://api.slack.com/methods/conversations.leave
 * @param options Request options.
 */
export declare function leaveConversation<T = Conversation.LeaveConversation.Response.OK>(options: Conversation.LeaveConversation.Options.HandledApi): Promise<Conversation.LeaveConversation.Response.OK>;
/**
 * Lists all channels in a Slack team.
 * Documentation: https://api.slack.com/methods/conversations.list
 * @param options Request options.
 */
export declare function getConversations<T = Conversation.GetConversations.Response.OK>(options: Conversation.GetConversations.Options.HandledApi): Promise<Conversation.GetConversations.Response.OK>;
/**
 * Retrieve members of a conversation.
 * Documentation: https://api.slack.com/methods/conversations.members
 * @param options Request options.
 */
export declare function getConversationMembers<T = Conversation.GetMembers.Response.OK>(options: Conversation.GetMembers.Options.HandledApi): Promise<Conversation.GetMembers.Response.OK>;
/**
 * Opens or resumes a direct message or multi-person direct message.
 * Documentation: https://api.slack.com/methods/conversations.open
 * @param options Request options.
 */
export declare function openConversation<T = Conversation.OpenConversation.Response.OK>(options: Conversation.OpenConversation.Options.HandledApi): Promise<Conversation.OpenConversation.Response.OK>;
/**
 * Renames a conversation.
 * Documentation: https://api.slack.com/methods/conversations.rename
 * @param options Request options.
 */
export declare function renameConversation<T = Conversation.RenameConversation.Response.OK>(options: Conversation.RenameConversation.Options.HandledApi): Promise<Conversation.RenameConversation.Response.OK>;
/**
 * Retrieve a thread of messages posted to a conversation
 * Documentation: https://api.slack.com/methods/conversations.replies
 * @param options Request options.
 */
export declare function getConversationReplies<T = Conversation.GetReplies.Response.OK>(options: Conversation.GetReplies.Options.HandledApi): Promise<Conversation.GetReplies.Response.OK>;
/**
 * Sets the purpose for a conversation.
 * Documentation: https://api.slack.com/methods/conversations.setPurpose
 * @param options Request options.
 */
export declare function setConversationPurpose<T = Conversation.SetPurpose.Response.OK>(options: Conversation.SetPurpose.Options.HandledApi): Promise<Conversation.SetPurpose.Response.OK>;
/**
 * Sets the topic for a conversation.
 * Documentation: https://api.slack.com/methods/conversations.setTopic
 * @param options Request options.
 */
export declare function setConversationTopic<T = Conversation.SetTopic.Response.OK>(options: Conversation.SetTopic.Options.HandledApi): Promise<Conversation.SetTopic.Response.OK>;
/**
 * Reverses conversation archival.
 * Documentation: https://api.slack.com/methods/conversations.unarchive
 * @param options Request options.
 */
export declare function unarchiveConversation<T = Conversation.UnarchiveConversation.Response.OK>(options: Conversation.UnarchiveConversation.Options.HandledApi): Promise<Conversation.UnarchiveConversation.Response.OK>;
//# sourceMappingURL=conversation.d.ts.map