import { archiveConversation as archiveConversationFn } from "../raw-api/conversation";
import { executeRequest } from "../handled-api/common";
import { closeConversation as closeConversationFn } from "../raw-api/conversation";
import { createConversation as createConversationFn } from "../raw-api/conversation";
import { getConversationHistory as getConversationHistoryFn } from "../raw-api/conversation";
import { getConversationInfo as getConversationInfoFn } from "../raw-api/conversation";
import { inviteUserToConversation as inviteUserToConversationFn } from "../raw-api/conversation";
import { joinConversation as joinConversationFn } from "../raw-api/conversation";
import { kickUserFromConversation as kickUserFromConversationFn } from "../raw-api/conversation";
import { leaveConversation as leaveConversationFn } from "../raw-api/conversation";
import { getConversations as getConversationsFn } from "../raw-api/conversation";
import { getConversationMembers as getConversationMembersFn } from "../raw-api/conversation";
import { openConversation as openConversationFn } from "../raw-api/conversation";
import { renameConversation as renameConversationFn } from "../raw-api/conversation";
import { getConversationReplies as getConversationRepliesFn } from "../raw-api/conversation";
import { setConversationPurpose as setConversationPurposeFn } from "../raw-api/conversation";
import { setConversationTopic as setConversationTopicFn } from "../raw-api/conversation";
import { unarchiveConversation as unarchiveConversationFn } from "../raw-api/conversation";
/**
 * Archives a conversation.
 * Documentation: https://api.slack.com/methods/conversations.archive
 * @param options Request options.
 */
export function archiveConversation(options) {
    return executeRequest(() => archiveConversationFn(options), options.errorStrategy);
}
/**
 * Closes a direct message or multi-person direct message.
 * Documentation: https://api.slack.com/methods/conversations.close
 * @param options Request options.
 */
export function closeConversation(options) {
    return executeRequest(() => closeConversationFn(options), options.errorStrategy);
}
/**
 * Initiates a public or private channel-based conversation
 * Documentation: https://api.slack.com/methods/conversations.create
 * @param options Request options.
 */
export function createConversation(options) {
    return executeRequest(() => createConversationFn(options), options.errorStrategy);
}
/**
 * Fetches a conversation's history of messages and events.
 * Documentation: https://api.slack.com/methods/conversations.history
 * @param options Request options.
 */
export function getConversationHistory(options) {
    return executeRequest(() => getConversationHistoryFn(options), options.errorStrategy);
}
/**
 * Retrieve information about a conversation.
 * Documentation: https://api.slack.com/methods/conversations.info
 * @param options Request options.
 */
export function getConversationInfo(options) {
    return executeRequest(() => getConversationInfoFn(options), options.errorStrategy);
}
/**
 * Invites users to a channel.
 * Documentation: https://api.slack.com/methods/conversations.invite
 * @param options Request options.
 */
export function inviteUserToConversation(options) {
    return executeRequest(() => inviteUserToConversationFn(options), options.errorStrategy);
}
/**
 * Joins an existing conversation.
 * Documentation: https://api.slack.com/methods/conversations.join
 * @param options Request options.
 */
export function joinConversation(options) {
    return executeRequest(() => joinConversationFn(options), options.errorStrategy);
}
/**
 * Removes a user from a conversation.
 * Documentation: https://api.slack.com/methods/conversations.kick
 * @param options Request options.
 */
export function kickUserFromConversation(options) {
    return executeRequest(() => kickUserFromConversationFn(options), options.errorStrategy);
}
/**
 * Leaves a conversation.
 * Documentation: https://api.slack.com/methods/conversations.leave
 * @param options Request options.
 */
export function leaveConversation(options) {
    return executeRequest(() => leaveConversationFn(options), options.errorStrategy);
}
/**
 * Lists all channels in a Slack team.
 * Documentation: https://api.slack.com/methods/conversations.list
 * @param options Request options.
 */
export function getConversations(options) {
    return executeRequest(() => getConversationsFn(options), options.errorStrategy);
}
/**
 * Retrieve members of a conversation.
 * Documentation: https://api.slack.com/methods/conversations.members
 * @param options Request options.
 */
export function getConversationMembers(options) {
    return executeRequest(() => getConversationMembersFn(options), options.errorStrategy);
}
/**
 * Opens or resumes a direct message or multi-person direct message.
 * Documentation: https://api.slack.com/methods/conversations.open
 * @param options Request options.
 */
export function openConversation(options) {
    return executeRequest(() => openConversationFn(options), options.errorStrategy);
}
/**
 * Renames a conversation.
 * Documentation: https://api.slack.com/methods/conversations.rename
 * @param options Request options.
 */
export function renameConversation(options) {
    return executeRequest(() => renameConversationFn(options), options.errorStrategy);
}
/**
 * Retrieve a thread of messages posted to a conversation
 * Documentation: https://api.slack.com/methods/conversations.replies
 * @param options Request options.
 */
export function getConversationReplies(options) {
    return executeRequest(() => getConversationRepliesFn(options), options.errorStrategy);
}
/**
 * Sets the purpose for a conversation.
 * Documentation: https://api.slack.com/methods/conversations.setPurpose
 * @param options Request options.
 */
export function setConversationPurpose(options) {
    return executeRequest(() => setConversationPurposeFn(options), options.errorStrategy);
}
/**
 * Sets the topic for a conversation.
 * Documentation: https://api.slack.com/methods/conversations.setTopic
 * @param options Request options.
 */
export function setConversationTopic(options) {
    return executeRequest(() => setConversationTopicFn(options), options.errorStrategy);
}
/**
 * Reverses conversation archival.
 * Documentation: https://api.slack.com/methods/conversations.unarchive
 * @param options Request options.
 */
export function unarchiveConversation(options) {
    return executeRequest(() => unarchiveConversationFn(options), options.errorStrategy);
}
