import { endDnd as endDndFn } from "../raw-api/dnd";
import { executeRequest } from "../handled-api/common";
import { endDndSnooze as endDndSnoozeFn } from "../raw-api/dnd";
import { getDndInfo as getDndInfoFn } from "../raw-api/dnd";
import { setDndSnooze as setDndSnoozeFn } from "../raw-api/dnd";
import { getDndTeamInfo as getDndTeamInfoFn } from "../raw-api/dnd";
/**
 * Ends the current user's Do Not Disturb session immediately.
 * Documentation: https://api.slack.com/methods/dnd.endDnd
 * @param options Request options.
 */
export function endDnd(options) {
    return executeRequest(() => endDndFn(options), options.errorStrategy);
}
/**
 * Ends the current user's snooze mode immediately.
 * Documentation: https://api.slack.com/methods/dnd.endSnooze
 * @param options Request options.
 */
export function endDndSnooze(options) {
    return executeRequest(() => endDndSnoozeFn(options), options.errorStrategy);
}
/**
 * Retrieves a user's current Do Not Disturb status.
 * Documentation: https://api.slack.com/methods/dnd.info
 * @param options Request options.
 */
export function getDndInfo(options) {
    return executeRequest(() => getDndInfoFn(options), options.errorStrategy);
}
/**
 * Turns on Do Not Disturb mode for the current user, or changes its duration.
 * Documentation: https://api.slack.com/methods/dnd.setSnooze
 * @param options Request options.
 */
export function setDndSnooze(options) {
    return executeRequest(() => setDndSnoozeFn(options), options.errorStrategy);
}
/**
 * Retrieves the Do Not Disturb status for up to 50 users on a team.
 * Documentation: https://api.slack.com/methods/dnd.teamInfo
 * @param options Request options.
 */
export function getDndTeamInfo(options) {
    return executeRequest(() => getDndTeamInfoFn(options), options.errorStrategy);
}
