import { deleteFile as deleteFileFn } from "../raw-api/file";
import { executeRequest } from "../handled-api/common";
import { getFileInfo as getFileInfoFn } from "../raw-api/file";
import { getFiles as getFilesFn } from "../raw-api/file";
import { uploadFile as uploadFileFn } from "../raw-api/file";
/**
 * Deletes a file.
 * Documentation: https://api.slack.com/methods/files.delete
 * @param options Request options.
 */
export function deleteFile(options) {
    return executeRequest(() => deleteFileFn(options), options.errorStrategy);
}
/**
 * Gets information about a file.
 * Documentation: https://api.slack.com/methods/files.info
 * @param options Request options.
 */
export function getFileInfo(options) {
    return executeRequest(() => getFileInfoFn(options), options.errorStrategy);
}
/**
 * List for a team, in a channel, or from a user with applied filters.
 * Documentation: https://api.slack.com/methods/files.list
 * @param options Request options.
 */
export function getFiles(options) {
    return executeRequest(() => getFilesFn(options), options.errorStrategy);
}
/**
 * Uploads or creates a file.
 * Documentation: https://api.slack.com/methods/files.upload
 * @param options Request options.
 */
export function uploadFile(options) {
    return executeRequest(() => uploadFileFn(options), options.errorStrategy);
}
