import { addRemoteFile as addRemoteFileFn } from "../../raw-api/file/remote";
import { executeRequest } from "../../handled-api/common";
import { getRemoteFileInfo as getRemoteFileInfoFn } from "../../raw-api/file/remote";
import { getRemoteFiles as getRemoteFilesFn } from "../../raw-api/file/remote";
import { removeRemoteFile as removeRemoteFileFn } from "../../raw-api/file/remote";
import { shareRemoteFile as shareRemoteFileFn } from "../../raw-api/file/remote";
import { updateRemoteFile as updateRemoteFileFn } from "../../raw-api/file/remote";
/**
 * Adds a file from a remote service
 * Documentation: https://api.slack.com/methods/files.remote.add
 * @param options Request options.
 */
export function addRemoteFile(options) {
    return executeRequest(() => addRemoteFileFn(options), options.errorStrategy);
}
/**
 * Retrieve information about a remote file added to Slack
 * Documentation: https://api.slack.com/methods/files.remote.info
 * @param options Request options.
 */
export function getRemoteFileInfo(options) {
    return executeRequest(() => getRemoteFileInfoFn(options), options.errorStrategy);
}
/**
 * Retrieve information about a remote file added to Slack
 * Documentation: https://api.slack.com/methods/files.remote.list
 * @param options Request options.
 */
export function getRemoteFiles(options) {
    return executeRequest(() => getRemoteFilesFn(options), options.errorStrategy);
}
/**
 * Remove a remote file.
 * Documentation: https://api.slack.com/methods/files.remote.remove
 * @param options Request options.
 */
export function removeRemoteFile(options) {
    return executeRequest(() => removeRemoteFileFn(options), options.errorStrategy);
}
/**
 * Share a remote file into a channel.
 * Documentation: https://api.slack.com/methods/files.remote.share
 * @param options Request options.
 */
export function shareRemoteFile(options) {
    return executeRequest(() => shareRemoteFileFn(options), options.errorStrategy);
}
/**
 * Updates an existing remote file.
 * Documentation: https://api.slack.com/methods/files.remote.update
 * @param options Request options.
 */
export function updateRemoteFile(options) {
    return executeRequest(() => updateRemoteFileFn(options), options.errorStrategy);
}
