import { addReaction as addReactionFn } from "../raw-api/reaction";
import { executeRequest } from "../handled-api/common";
import { getReaction as getReactionFn } from "../raw-api/reaction";
import { getReactions as getReactionsFn } from "../raw-api/reaction";
import { removeReaction as removeReactionFn } from "../raw-api/reaction";
/**
 * Adds a reaction to an item.
 * Documentation: https://api.slack.com/methods/reactions.add
 * @param options Request options.
 */
export function addReaction(options) {
    return executeRequest(() => addReactionFn(options), options.errorStrategy);
}
/**
 * Gets reactions for an item.
 * Documentation: https://api.slack.com/methods/reactions.get
 * @param options Request options.
 */
export function getReaction(options) {
    return executeRequest(() => getReactionFn(options), options.errorStrategy);
}
/**
 * Lists reactions made by a user.
 * Documentation: https://api.slack.com/methods/reactions.list
 * @param options Request options.
 */
export function getReactions(options) {
    return executeRequest(() => getReactionsFn(options), options.errorStrategy);
}
/**
 * Removes a reaction from an item.
 * Documentation: https://api.slack.com/methods/reactions.remove
 * @param options Request options.
 */
export function removeReaction(options) {
    return executeRequest(() => removeReactionFn(options), options.errorStrategy);
}
