import { getReminders as getRemindersFn } from "../raw-api/reminders";
import { executeRequest } from "../handled-api/common";
import { getReminderInfo as getReminderInfoFn } from "../raw-api/reminders";
import { deleteReminder as deleteReminderFn } from "../raw-api/reminders";
import { completeReminder as completeReminderFn } from "../raw-api/reminders";
import { addReminder as addReminderFn } from "../raw-api/reminders";
/**
 * Lists all reminders created by or for a given user.
 * Documentation: https://api.slack.com/methods/reminders.list
 * @param options Request options.
 */
export function getReminders(options) {
    return executeRequest(() => getRemindersFn(options), options.errorStrategy);
}
/**
 * Gets information about a reminder.
 * Documentation: https://api.slack.com/methods/reminders.info
 * @param options Request options.
 */
export function getReminderInfo(options) {
    return executeRequest(() => getReminderInfoFn(options), options.errorStrategy);
}
/**
 * Deletes a reminder.
 * Documentation: https://api.slack.com/methods/reminders.delete
 * @param options Request options.
 */
export function deleteReminder(options) {
    return executeRequest(() => deleteReminderFn(options), options.errorStrategy);
}
/**
 * Marks a reminder as complete.
 * Documentation: https://api.slack.com/methods/reminders.complete
 * @param options Request options.
 */
export function completeReminder(options) {
    return executeRequest(() => completeReminderFn(options), options.errorStrategy);
}
/**
 * Creates a reminder.
 * Documentation: https://api.slack.com/methods/reminders.add
 * @param options Request options.
 */
export function addReminder(options) {
    return executeRequest(() => addReminderFn(options), options.errorStrategy);
}
