import { getTeamAccessLogs as getTeamAccessLogsFn } from "../raw-api/team";
import { executeRequest } from "../handled-api/common";
import { getTeamBillableInfo as getTeamBillableInfoFn } from "../raw-api/team";
import { getTeamInfo as getTeamInfoFn } from "../raw-api/team";
import { getTeamIntegrationLogs as getTeamIntegrationLogsFn } from "../raw-api/team";
/**
 * Gets the access logs for the current team.
 * Documentation: https://api.slack.com/methods/team.accessLogs
 * @param options Request options.
 */
export function getTeamAccessLogs(options) {
    return executeRequest(() => getTeamAccessLogsFn(options), options.errorStrategy);
}
/**
 * Gets billable users information for the current team.
 * Documentation: https://api.slack.com/methods/team.billableInfo
 * @param options Request options.
 */
export function getTeamBillableInfo(options) {
    return executeRequest(() => getTeamBillableInfoFn(options), options.errorStrategy);
}
/**
 * Gets information about the current team.
 * Documentation: https://api.slack.com/methods/team.info
 * @param options Request options.
 */
export function getTeamInfo(options) {
    return executeRequest(() => getTeamInfoFn(options), options.errorStrategy);
}
/**
 * Gets the integration logs for the current team.
 * Documentation: https://api.slack.com/methods/team.integrationLogs
 * @param options Request options.
 */
export function getTeamIntegrationLogs(options) {
    return executeRequest(() => getTeamIntegrationLogsFn(options), options.errorStrategy);
}
