import { User } from "../types/user";
/**
 * Find a user with an email address.
 * Documentation: https://api.slack.com/methods/users.lookupByEmail
 * @param options Request options.
 */
export declare function getUserByEmail<T = User.GetUserByEmail.Response.OK>(options: User.GetUserByEmail.Options.HandledApi): Promise<User.GetUserByEmail.Response.OK>;
/**
 * Lists all users in a Slack team.
 * Documentation: https://api.slack.com/methods/users.list
 * @param options Request options.
 */
export declare function getUsers<T = User.GetUsers.Response.OK>(options: User.GetUsers.Options.HandledApi): Promise<User.GetUsers.Response.OK>;
/**
 * Gets information about a user.
 * Documentation: https://api.slack.com/methods/users.info
 * @param options Request options.
 */
export declare function getUserInfo<T = User.GetInfo.Response.OK>(options: User.GetInfo.Options.HandledApi): Promise<User.GetInfo.Response.OK>;
/**
 * Get a user's identity.
 * Documentation: https://api.slack.com/methods/users.identity
 * @param options Request options.
 */
export declare function getUserIdentity<T = User.GetIdentity.Response.OK>(options: User.GetIdentity.Options.HandledApi): Promise<any>;
/**
 * List conversations the calling user may access.
 * Documentation: https://api.slack.com/methods/users.conversations
 * @param options Request options.
 */
export declare function getUserConversations<T = User.GetConversations.Response.OK>(options: User.GetConversations.Options.HandledApi): Promise<User.GetConversations.Response.OK>;
/**
 * Gets user presence information.
 * Documentation: https://api.slack.com/methods/users.getPresence
 * @param options Request options.
 */
export declare function getUserPresence<T = User.GetPresence.Response.OK>(options: User.GetPresence.Options.HandledApi): Promise<User.GetPresence.Response.OK>;
/**
 * Manually sets user presence.
 * Documentation: https://api.slack.com/methods/users.setPresence
 * @param options Request options.
 */
export declare function setUserPresence<T = User.SetPresence.Response.OK>(options: User.SetPresence.Options.HandledApi): Promise<User.SetPresence.Response.OK>;
//# sourceMappingURL=user.d.ts.map