import { getUserByEmail as getUserByEmailFn } from "../raw-api/user";
import { executeRequest } from "../handled-api/common";
import { getUsers as getUsersFn } from "../raw-api/user";
import { getUserInfo as getUserInfoFn } from "../raw-api/user";
import { getUserIdentity as getUserIdentityFn } from "../raw-api/user";
import { getUserConversations as getUserConversationsFn } from "../raw-api/user";
import { getUserPresence as getUserPresenceFn } from "../raw-api/user";
import { setUserPresence as setUserPresenceFn } from "../raw-api/user";
/**
 * Find a user with an email address.
 * Documentation: https://api.slack.com/methods/users.lookupByEmail
 * @param options Request options.
 */
export function getUserByEmail(options) {
    return executeRequest(() => getUserByEmailFn(options), options.errorStrategy);
}
/**
 * Lists all users in a Slack team.
 * Documentation: https://api.slack.com/methods/users.list
 * @param options Request options.
 */
export function getUsers(options) {
    return executeRequest(() => getUsersFn(options), options.errorStrategy);
}
/**
 * Gets information about a user.
 * Documentation: https://api.slack.com/methods/users.info
 * @param options Request options.
 */
export function getUserInfo(options) {
    return executeRequest(() => getUserInfoFn(options), options.errorStrategy);
}
/**
 * Get a user's identity.
 * Documentation: https://api.slack.com/methods/users.identity
 * @param options Request options.
 */
export function getUserIdentity(options) {
    return executeRequest(() => getUserIdentityFn(options), options.errorStrategy);
}
/**
 * List conversations the calling user may access.
 * Documentation: https://api.slack.com/methods/users.conversations
 * @param options Request options.
 */
export function getUserConversations(options) {
    return executeRequest(() => getUserConversationsFn(options), options.errorStrategy);
}
/**
 * Gets user presence information.
 * Documentation: https://api.slack.com/methods/users.getPresence
 * @param options Request options.
 */
export function getUserPresence(options) {
    return executeRequest(() => getUserPresenceFn(options), options.errorStrategy);
}
/**
 * Manually sets user presence.
 * Documentation: https://api.slack.com/methods/users.setPresence
 * @param options Request options.
 */
export function setUserPresence(options) {
    return executeRequest(() => setUserPresenceFn(options), options.errorStrategy);
}
