import { createUserGroup as createUserGroupFn } from "../raw-api/userGroup";
import { executeRequest } from "../handled-api/common";
import { disableUserGroup as disableUserGroupFn } from "../raw-api/userGroup";
import { enableUserGroup as enableUserGroupFn } from "../raw-api/userGroup";
import { getUserGroups as getUserGroupsFn } from "../raw-api/userGroup";
import { updateUserGroup as updateUserGroupFn } from "../raw-api/userGroup";
/**
 * Create a User Group
 * Documentation: https://api.slack.com/methods/usergroups.create
 * @param options Request options.
 */
export function createUserGroup(options) {
    return executeRequest(() => createUserGroupFn(options), options.errorStrategy);
}
/**
 * Disable an existing User Group
 * Documentation: https://api.slack.com/methods/usergroups.disable
 * @param options Request options.
 */
export function disableUserGroup(options) {
    return executeRequest(() => disableUserGroupFn(options), options.errorStrategy);
}
/**
 * Enable a User Group
 * Documentation: https://api.slack.com/methods/usergroups.enable
 * @param options Request options.
 */
export function enableUserGroup(options) {
    return executeRequest(() => enableUserGroupFn(options), options.errorStrategy);
}
/**
 * List all User Groups for a team
 * Documentation: https://api.slack.com/methods/usergroups.list
 * @param options Request options.
 */
export function getUserGroups(options) {
    return executeRequest(() => getUserGroupsFn(options), options.errorStrategy);
}
/**
 * Update an existing User Group
 * Documentation: https://api.slack.com/methods/usergroups.update
 * @param options Request options.
 */
export function updateUserGroup(options) {
    return executeRequest(() => updateUserGroupFn(options), options.errorStrategy);
}
