import { updateView as updateViewFn } from "../raw-api/view";
import { executeRequest } from "../handled-api/common";
import { pushView as pushViewFn } from "../raw-api/view";
import { publishView as publishViewFn } from "../raw-api/view";
import { openView as openViewFn } from "../raw-api/view";
/**
 * Update an existing view.
 * Documentation: https://api.slack.com/methods/views.update
 * @param options Request options.
 */
export function updateView(options) {
    return executeRequest(() => updateViewFn(options), options.errorStrategy);
}
/**
 * Push a view onto the stack of a root view.
 * Documentation: https://api.slack.com/methods/views.push
 * @param options Request options.
 */
export function pushView(options) {
    return executeRequest(() => pushViewFn(options), options.errorStrategy);
}
/**
 * Publish a static view for a User.
 * Documentation: https://api.slack.com/methods/views.publish
 * @param options Request options.
 */
export function publishView(options) {
    return executeRequest(() => publishViewFn(options), options.errorStrategy);
}
/**
 * Open a view for a user.
 * Documentation: https://api.slack.com/methods/views.open
 * @param options Request options.
 */
export function openView(options) {
    return executeRequest(() => openViewFn(options), options.errorStrategy);
}
