import { httpPost } from "../../raw-api/common";
import { httpGet } from "../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
/**
 * Set an existing guest user, admin user, or owner to be a regular user.
 * Documentation: https://api.slack.com/methods/admin.users.setRegular
 * @param options Request options.
 */
export function adminSetRegularUser(options) {
    const { connectionId: instanceId, headers, body, userId } = options;
    const customParams = { userId };
    return httpPost(instanceId, `/api/admin.users.setRegular`, body, headers, customParams);
}
/**
 * Set an existing guest, regular user, or admin user to be a workspace owner.
 * Documentation: https://api.slack.com/methods/admin.users.setOwner
 * @param options Request options.
 */
export function adminSetOwnerUser(options) {
    const { connectionId: instanceId, headers, body, userId } = options;
    const customParams = { userId };
    return httpPost(instanceId, `/api/admin.users.setOwner`, body, headers, customParams);
}
/**
 * Set an expiration for a guest user
 * Documentation: https://api.slack.com/methods/admin.users.setExpiration
 * @param options Request options.
 */
export function adminSetUserExpiration(options) {
    const { connectionId: instanceId, headers, body, userId } = options;
    const customParams = { userId };
    return httpPost(instanceId, `/api/admin.users.setExpiration`, body, headers, customParams);
}
/**
 * Set an existing guest, regular user, or owner to be an admin user.
 * Documentation: https://api.slack.com/methods/admin.users.setAdmin
 * @param options Request options.
 */
export function adminSetAdminUser(options) {
    const { connectionId: instanceId, headers, body, userId } = options;
    const customParams = { userId };
    return httpPost(instanceId, `/api/admin.users.setAdmin`, body, headers, customParams);
}
/**
 * Remove a user from a workspace.
 * Documentation: https://api.slack.com/methods/admin.users.remove
 * @param options Request options.
 */
export function adminRemoveUser(options) {
    const { connectionId: instanceId, headers, body, userId } = options;
    const customParams = { userId };
    return httpPost(instanceId, `/api/admin.users.remove`, body, headers, customParams);
}
/**
 * List users on a workspace
 * Documentation: https://api.slack.com/methods/admin.users.list
 * @param options Request options.
 */
export function adminGetUsers(options) {
    const { connectionId: instanceId, headers, team_id, cursor, limit, userId } = options;
    const queryParams = { team_id, cursor, limit };
    const customParams = { userId };
    return httpGet(instanceId, constructUrl(`/api/admin.users.list`, queryParams), headers, customParams);
}
/**
 * Invite a user to a workspace.
 * Documentation: https://api.slack.com/methods/admin.users.invite
 * @param options Request options.
 */
export function adminInviteUser(options) {
    const { connectionId: instanceId, headers, body, userId } = options;
    const customParams = { userId };
    return httpPost(instanceId, `/api/admin.users.invite`, body, headers, customParams);
}
/**
 * Add an Enterprise user to a workspace.
 * Documentation: https://api.slack.com/methods/admin.users.assign
 * @param options Request options.
 */
export function adminAssignUser(options) {
    const { connectionId: instanceId, headers, body, userId } = options;
    const customParams = { userId };
    return httpPost(instanceId, `/api/admin.users.assign`, body, headers, customParams);
}
