import { httpPost } from "../raw-api/common";
import { httpGet } from "../raw-api/common";
import { constructUrl } from "@avst-api/commons";
/**
 * Deletes a message.
 * Documentation: https://api.slack.com/methods/chat.delete
 * @param options Request options.
 */
export function deleteChatMessage(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/chat.delete`, body, headers, customParams);
}
/**
 * Deletes a pending scheduled message from the queue.
 * Documentation: https://api.slack.com/methods/chat.deleteScheduledMessage
 * @param options Request options.
 */
export function deleteChatScheduledMessage(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/chat.deleteScheduledMessage`, body, headers, customParams);
}
/**
 * Retrieve a permalink URL for a specific extant message
 * Documentation: https://api.slack.com/methods/chat.getPermalink
 * @param options Request options.
 */
export function getChatPermalink(options) {
    const { connectionId: instanceId, headers, channel, message_ts, preferredAuth, userId } = options;
    const queryParams = { channel, message_ts };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/chat.getPermalink`, queryParams), headers, customParams);
}
/**
 * Share a me message into a channel.
 * Documentation: https://api.slack.com/methods/chat.meMessage
 * @param options Request options.
 */
export function postChatMeMessage(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/chat.meMessage`, body, headers, customParams);
}
/**
 * Sends an ephemeral message to a user in a channel.
 * Documentation: https://api.slack.com/methods/chat.postEphemeral
 * @param options Request options.
 */
export function postChatEphemeralMessage(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/chat.postEphemeral`, body, headers, customParams);
}
/**
 * Sends a message to a channel.
 * Documentation: https://api.slack.com/methods/chat.postMessage
 * @param options Request options.
 */
export function postChatMessage(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/chat.postMessage`, body, headers, customParams);
}
/**
 * Schedules a message to be sent to a channel.
 * Documentation: https://api.slack.com/methods/chat.scheduleMessage
 * @param options Request options.
 */
export function scheduleChatMessage(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/chat.scheduleMessage`, body, headers, customParams);
}
/**
 * Provide custom unfurl behavior for user-posted URLs
 * Documentation: https://api.slack.com/methods/chat.unfurl
 * @param options Request options.
 */
export function unfurlChatMessage(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/chat.unfurl`, body, headers, customParams);
}
/**
 * Updates a message.
 * Documentation: https://api.slack.com/methods/chat.update
 * @param options Request options.
 */
export function updateChatMessage(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/chat.update`, body, headers, customParams);
}
