import { UnexpectedError, performHttpCall } from '@avst-api/commons';
export function httpGet(connection, urlPath, headers, customParams) {
    return performHttpCall(connection, urlPath, 'GET', undefined, checkCustomParams(headers, customParams));
}
export function httpPost(connection, urlPath, request, headers, customParams) {
    return performHttpCall(connection, urlPath, 'POST', request, checkCustomParams(headers, customParams));
}
export function httpPut(connection, urlPath, request, headers, customParams) {
    return performHttpCall(connection, urlPath, 'PUT', request, checkCustomParams(headers, customParams));
}
export function httpDelete(connection, urlPath, headers, customParams) {
    return performHttpCall(connection, urlPath, 'DELETE', undefined, checkCustomParams(headers, customParams));
}
function checkCustomParams(headers, customParams) {
    const newHeaders = { ...headers };
    if (customParams && customParams.preferredAuth) {
        const preferredAuth = customParams.preferredAuth;
        if (preferredAuth !== 'USER' && preferredAuth !== 'BOT') {
            throw new UnexpectedError(undefined, 'Preferred auth can only contain following values: USER, BOT');
        }
        newHeaders['X-SLACK-PREFERRED-AUTH'] = preferredAuth;
    }
    if (customParams && customParams.userId) {
        const userId = customParams.userId;
        newHeaders['X-SLACK-AUTH-USERID'] = userId;
    }
    if (customParams && customParams.responseUrl) {
        const reponseUrl = customParams.responseUrl;
        newHeaders['Slack-Response-Url'] = reponseUrl;
    }
    return newHeaders;
}
