import { Conversation } from "../types/conversation";
/**
 * Archives a conversation.
 * Documentation: https://api.slack.com/methods/conversations.archive
 * @param options Request options.
 */
export declare function archiveConversation(options: Conversation.ArchiveConversation.Options.RawApi): Promise<import("@avst-api/commons").Response<Conversation.ArchiveConversation.Response.OK | Conversation.ArchiveConversation.Response.Error>>;
/**
 * Closes a direct message or multi-person direct message.
 * Documentation: https://api.slack.com/methods/conversations.close
 * @param options Request options.
 */
export declare function closeConversation(options: Conversation.CloseConversation.Options.RawApi): Promise<import("@avst-api/commons").Response<Conversation.CloseConversation.Response.OK | Conversation.CloseConversation.Response.Error>>;
/**
 * Initiates a public or private channel-based conversation
 * Documentation: https://api.slack.com/methods/conversations.create
 * @param options Request options.
 */
export declare function createConversation(options: Conversation.CreateConversation.Options.RawApi): Promise<import("@avst-api/commons").Response<Conversation.CreateConversation.Response.OK | Conversation.CreateConversation.Response.Error>>;
/**
 * Fetches a conversation's history of messages and events.
 * Documentation: https://api.slack.com/methods/conversations.history
 * @param options Request options.
 */
export declare function getConversationHistory(options: Conversation.GetHistory.Options.RawApi): Promise<import("@avst-api/commons").Response<Conversation.GetHistory.Response.OK | Conversation.GetHistory.Response.Error>>;
/**
 * Retrieve information about a conversation.
 * Documentation: https://api.slack.com/methods/conversations.info
 * @param options Request options.
 */
export declare function getConversationInfo(options: Conversation.GetInfo.Options.RawApi): Promise<import("@avst-api/commons").Response<Conversation.GetInfo.Response.OK | Conversation.GetInfo.Response.Error>>;
/**
 * Invites users to a channel.
 * Documentation: https://api.slack.com/methods/conversations.invite
 * @param options Request options.
 */
export declare function inviteUserToConversation(options: Conversation.InviteUser.Options.RawApi): Promise<import("@avst-api/commons").Response<Conversation.InviteUser.Response.OK | Conversation.InviteUser.Response.Error>>;
/**
 * Joins an existing conversation.
 * Documentation: https://api.slack.com/methods/conversations.join
 * @param options Request options.
 */
export declare function joinConversation(options: Conversation.JoinConversation.Options.RawApi): Promise<import("@avst-api/commons").Response<Conversation.JoinConversation.Response.OK | Conversation.JoinConversation.Response.Error>>;
/**
 * Removes a user from a conversation.
 * Documentation: https://api.slack.com/methods/conversations.kick
 * @param options Request options.
 */
export declare function kickUserFromConversation(options: Conversation.KickUser.Options.RawApi): Promise<import("@avst-api/commons").Response<Conversation.KickUser.Response.OK | Conversation.KickUser.Response.Error>>;
/**
 * Leaves a conversation.
 * Documentation: https://api.slack.com/methods/conversations.leave
 * @param options Request options.
 */
export declare function leaveConversation(options: Conversation.LeaveConversation.Options.RawApi): Promise<import("@avst-api/commons").Response<Conversation.LeaveConversation.Response.OK | Conversation.LeaveConversation.Response.Error>>;
/**
 * Lists all channels in a Slack team.
 * Documentation: https://api.slack.com/methods/conversations.list
 * @param options Request options.
 */
export declare function getConversations(options: Conversation.GetConversations.Options.RawApi): Promise<import("@avst-api/commons").Response<Conversation.GetConversations.Response.OK | Conversation.GetConversations.Response.Error>>;
/**
 * Retrieve members of a conversation.
 * Documentation: https://api.slack.com/methods/conversations.members
 * @param options Request options.
 */
export declare function getConversationMembers(options: Conversation.GetMembers.Options.RawApi): Promise<import("@avst-api/commons").Response<Conversation.GetMembers.Response.OK | Conversation.GetMembers.Response.Error>>;
/**
 * Opens or resumes a direct message or multi-person direct message.
 * Documentation: https://api.slack.com/methods/conversations.open
 * @param options Request options.
 */
export declare function openConversation(options: Conversation.OpenConversation.Options.RawApi): Promise<import("@avst-api/commons").Response<Conversation.OpenConversation.Response.OK | Conversation.OpenConversation.Response.Error>>;
/**
 * Renames a conversation.
 * Documentation: https://api.slack.com/methods/conversations.rename
 * @param options Request options.
 */
export declare function renameConversation(options: Conversation.RenameConversation.Options.RawApi): Promise<import("@avst-api/commons").Response<Conversation.RenameConversation.Response.OK | Conversation.RenameConversation.Response.Error>>;
/**
 * Retrieve a thread of messages posted to a conversation
 * Documentation: https://api.slack.com/methods/conversations.replies
 * @param options Request options.
 */
export declare function getConversationReplies(options: Conversation.GetReplies.Options.RawApi): Promise<import("@avst-api/commons").Response<Conversation.GetReplies.Response.OK | Conversation.GetReplies.Response.Error>>;
/**
 * Sets the purpose for a conversation.
 * Documentation: https://api.slack.com/methods/conversations.setPurpose
 * @param options Request options.
 */
export declare function setConversationPurpose(options: Conversation.SetPurpose.Options.RawApi): Promise<import("@avst-api/commons").Response<Conversation.SetPurpose.Response.OK | Conversation.SetPurpose.Response.Error>>;
/**
 * Sets the topic for a conversation.
 * Documentation: https://api.slack.com/methods/conversations.setTopic
 * @param options Request options.
 */
export declare function setConversationTopic(options: Conversation.SetTopic.Options.RawApi): Promise<import("@avst-api/commons").Response<Conversation.SetTopic.Response.OK | Conversation.SetTopic.Response.Error>>;
/**
 * Reverses conversation archival.
 * Documentation: https://api.slack.com/methods/conversations.unarchive
 * @param options Request options.
 */
export declare function unarchiveConversation(options: Conversation.UnarchiveConversation.Options.RawApi): Promise<import("@avst-api/commons").Response<Conversation.UnarchiveConversation.Response.OK | Conversation.UnarchiveConversation.Response.Error>>;
//# sourceMappingURL=conversation.d.ts.map