import { httpPost } from "../raw-api/common";
import { httpGet } from "../raw-api/common";
import { constructUrl } from "@avst-api/commons";
/**
 * Ends the current user's Do Not Disturb session immediately.
 * Documentation: https://api.slack.com/methods/dnd.endDnd
 * @param options Request options.
 */
export function endDnd(options) {
    const { connectionId: instanceId, headers, userId } = options;
    const customParams = { userId };
    return httpPost(instanceId, `/api/dnd.endDnd`, undefined, headers, customParams);
}
/**
 * Ends the current user's snooze mode immediately.
 * Documentation: https://api.slack.com/methods/dnd.endSnooze
 * @param options Request options.
 */
export function endDndSnooze(options) {
    const { connectionId: instanceId, headers, userId } = options;
    const customParams = { userId };
    return httpPost(instanceId, `/api/dnd.endSnooze`, undefined, headers, customParams);
}
/**
 * Retrieves a user's current Do Not Disturb status.
 * Documentation: https://api.slack.com/methods/dnd.info
 * @param options Request options.
 */
export function getDndInfo(options) {
    const { connectionId: instanceId, headers, user, preferredAuth, userId } = options;
    const queryParams = { user };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/dnd.info`, queryParams), headers, customParams);
}
/**
 * Turns on Do Not Disturb mode for the current user, or changes its duration.
 * Documentation: https://api.slack.com/methods/dnd.setSnooze
 * @param options Request options.
 */
export function setDndSnooze(options) {
    const { connectionId: instanceId, headers, num_minutes, userId } = options;
    const queryParams = { num_minutes };
    const customParams = { userId };
    return httpGet(instanceId, constructUrl(`/api/dnd.setSnooze`, queryParams), headers, customParams);
}
/**
 * Retrieves the Do Not Disturb status for up to 50 users on a team.
 * Documentation: https://api.slack.com/methods/dnd.teamInfo
 * @param options Request options.
 */
export function getDndTeamInfo(options) {
    const { connectionId: instanceId, headers, users, preferredAuth, userId } = options;
    const queryParams = { users };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/dnd.teamInfo`, queryParams), headers, customParams);
}
