import { httpPost } from "../raw-api/common";
import { httpGet } from "../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { transformToFormData } from "@avst-api/commons";
/**
 * Deletes a file.
 * Documentation: https://api.slack.com/methods/files.delete
 * @param options Request options.
 */
export function deleteFile(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/files.delete`, body, headers, customParams);
}
/**
 * Gets information about a file.
 * Documentation: https://api.slack.com/methods/files.info
 * @param options Request options.
 */
export function getFileInfo(options) {
    const { connectionId: instanceId, headers, file, count, page, limit, cursor, preferredAuth, userId } = options;
    const queryParams = { file, count, page, limit, cursor };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/files.info`, queryParams), headers, customParams);
}
/**
 * List for a team, in a channel, or from a user with applied filters.
 * Documentation: https://api.slack.com/methods/files.list
 * @param options Request options.
 */
export function getFiles(options) {
    const { connectionId: instanceId, headers, user, channel, ts_from, ts_to, types, count, page, show_files_hidden_by_limit, preferredAuth, userId } = options;
    const queryParams = { user, channel, ts_from, ts_to, types, count, page, show_files_hidden_by_limit };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/files.list`, queryParams), headers, customParams);
}
/**
 * Uploads or creates a file.
 * Documentation: https://api.slack.com/methods/files.upload
 * @param options Request options.
 */
export function uploadFile(options) {
    const { connectionId: instanceId, body, headers, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    if (body.content) {
        return httpGet(instanceId, constructUrl("/api/files.upload", body), headers, customParams);
    }
    return httpPost(instanceId, "/api/files.upload", transformToFormData(body), headers, customParams);
}
