import { httpGet } from "../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
/**
 * Adds a file from a remote service
 * Documentation: https://api.slack.com/methods/files.remote.add
 * @param options Request options.
 */
export function addRemoteFile(options) {
    const { connectionId: instanceId, headers, external_id, title, filetype, external_url, preview_image, indexable_file_contents } = options;
    const queryParams = { external_id, title, filetype, external_url, preview_image, indexable_file_contents };
    return httpGet(instanceId, constructUrl(`/api/files.remote.add`, queryParams), headers);
}
/**
 * Retrieve information about a remote file added to Slack
 * Documentation: https://api.slack.com/methods/files.remote.info
 * @param options Request options.
 */
export function getRemoteFileInfo(options) {
    const { connectionId: instanceId, headers, file, external_id, preferredAuth, userId } = options;
    const queryParams = { file, external_id };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/files.remote.info`, queryParams), headers, customParams);
}
/**
 * Retrieve information about a remote file added to Slack
 * Documentation: https://api.slack.com/methods/files.remote.list
 * @param options Request options.
 */
export function getRemoteFiles(options) {
    const { connectionId: instanceId, headers, channel, ts_from, ts_to, limit, cursor, preferredAuth, userId } = options;
    const queryParams = { channel, ts_from, ts_to, limit, cursor };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/files.remote.list`, queryParams), headers, customParams);
}
/**
 * Remove a remote file.
 * Documentation: https://api.slack.com/methods/files.remote.remove
 * @param options Request options.
 */
export function removeRemoteFile(options) {
    const { connectionId: instanceId, headers, file, external_id } = options;
    const queryParams = { file, external_id };
    return httpGet(instanceId, constructUrl(`/api/files.remote.remove`, queryParams), headers);
}
/**
 * Share a remote file into a channel.
 * Documentation: https://api.slack.com/methods/files.remote.share
 * @param options Request options.
 */
export function shareRemoteFile(options) {
    const { connectionId: instanceId, headers, file, external_id, channels, preferredAuth, userId } = options;
    const queryParams = { file, external_id, channels };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/files.remote.share`, queryParams), headers, customParams);
}
/**
 * Updates an existing remote file.
 * Documentation: https://api.slack.com/methods/files.remote.update
 * @param options Request options.
 */
export function updateRemoteFile(options) {
    const { connectionId: instanceId, headers, file, external_id, title, filetype, external_url, preview_image, indexable_file_contents } = options;
    const queryParams = { file, external_id, title, filetype, external_url, preview_image, indexable_file_contents };
    return httpGet(instanceId, constructUrl(`/api/files.remote.update`, queryParams), headers);
}
