import { httpPost } from "../raw-api/common";
import { httpGet } from "../raw-api/common";
import { constructUrl } from "@avst-api/commons";
/**
 * Un-pins an item from a channel.
 * Documentation: https://api.slack.com/methods/pins.remove
 * @param options Request options.
 */
export function removePin(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/pins.remove`, body, headers, customParams);
}
/**
 * Lists items pinned to a channel.
 * Documentation: https://api.slack.com/methods/pins.list
 * @param options Request options.
 */
export function getPins(options) {
    const { connectionId: instanceId, headers, channel, preferredAuth, userId } = options;
    const queryParams = { channel };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/pins.list`, queryParams), headers, customParams);
}
/**
 * Pins an item to a channel.
 * Documentation: https://api.slack.com/methods/pins.add
 * @param options Request options.
 */
export function addPin(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/pins.add`, body, headers, customParams);
}
