import { httpPost } from "../raw-api/common";
import { httpGet } from "../raw-api/common";
import { constructUrl } from "@avst-api/commons";
/**
 * Adds a reaction to an item.
 * Documentation: https://api.slack.com/methods/reactions.add
 * @param options Request options.
 */
export function addReaction(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/reactions.add`, body, headers, customParams);
}
/**
 * Gets reactions for an item.
 * Documentation: https://api.slack.com/methods/reactions.get
 * @param options Request options.
 */
export function getReaction(options) {
    const { connectionId: instanceId, headers, channel, file, file_comment, full, timestamp, preferredAuth, userId } = options;
    const queryParams = { channel, file, file_comment, full, timestamp };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/reactions.get`, queryParams), headers, customParams);
}
/**
 * Lists reactions made by a user.
 * Documentation: https://api.slack.com/methods/reactions.list
 * @param options Request options.
 */
export function getReactions(options) {
    const { connectionId: instanceId, headers, user, full, count, page, cursor, limit, preferredAuth, userId } = options;
    const queryParams = { user, full, count, page, cursor, limit };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/reactions.list`, queryParams), headers, customParams);
}
/**
 * Removes a reaction from an item.
 * Documentation: https://api.slack.com/methods/reactions.remove
 * @param options Request options.
 */
export function removeReaction(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/reactions.remove`, body, headers, customParams);
}
