import { httpGet } from "../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpPost } from "../raw-api/common";
/**
 * Lists all reminders created by or for a given user.
 * Documentation: https://api.slack.com/methods/reminders.list
 * @param options Request options.
 */
export function getReminders(options) {
    const { connectionId: instanceId, headers, team_id, userId } = options;
    const queryParams = { team_id };
    const customParams = { userId };
    return httpGet(instanceId, constructUrl(`/api/reminders.list`, queryParams), headers, customParams);
}
/**
 * Gets information about a reminder.
 * Documentation: https://api.slack.com/methods/reminders.info
 * @param options Request options.
 */
export function getReminderInfo(options) {
    const { connectionId: instanceId, headers, reminder, team_id, userId } = options;
    const queryParams = { reminder, team_id };
    const customParams = { userId };
    return httpGet(instanceId, constructUrl(`/api/reminders.info`, queryParams), headers, customParams);
}
/**
 * Deletes a reminder.
 * Documentation: https://api.slack.com/methods/reminders.delete
 * @param options Request options.
 */
export function deleteReminder(options) {
    const { connectionId: instanceId, headers, body, userId } = options;
    const customParams = { userId };
    return httpPost(instanceId, `/api/reminders.delete`, body, headers, customParams);
}
/**
 * Marks a reminder as complete.
 * Documentation: https://api.slack.com/methods/reminders.complete
 * @param options Request options.
 */
export function completeReminder(options) {
    const { connectionId: instanceId, headers, body, userId } = options;
    const customParams = { userId };
    return httpPost(instanceId, `/api/reminders.complete`, body, headers, customParams);
}
/**
 * Creates a reminder.
 * Documentation: https://api.slack.com/methods/reminders.add
 * @param options Request options.
 */
export function addReminder(options) {
    const { connectionId: instanceId, headers, body, userId } = options;
    const customParams = { userId };
    return httpPost(instanceId, `/api/reminders.add`, body, headers, customParams);
}
