import { httpGet } from "../raw-api/common";
import { constructUrl } from "@avst-api/commons";
/**
 * Gets the access logs for the current team.
 * Documentation: https://api.slack.com/methods/team.accessLogs
 * @param options Request options.
 */
export function getTeamAccessLogs(options) {
    const { connectionId: instanceId, headers, count, page, before, userId } = options;
    const queryParams = { count, page, before };
    const customParams = { userId };
    return httpGet(instanceId, constructUrl(`/api/team.accessLogs`, queryParams), headers, customParams);
}
/**
 * Gets billable users information for the current team.
 * Documentation: https://api.slack.com/methods/team.billableInfo
 * @param options Request options.
 */
export function getTeamBillableInfo(options) {
    const { connectionId: instanceId, headers, user, userId } = options;
    const queryParams = { user };
    const customParams = { userId };
    return httpGet(instanceId, constructUrl(`/api/team.billableInfo`, queryParams), headers, customParams);
}
/**
 * Gets information about the current team.
 * Documentation: https://api.slack.com/methods/team.info
 * @param options Request options.
 */
export function getTeamInfo(options) {
    const { connectionId: instanceId, headers, team, preferredAuth, userId } = options;
    const queryParams = { team };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/team.info`, queryParams), headers, customParams);
}
/**
 * Gets the integration logs for the current team.
 * Documentation: https://api.slack.com/methods/team.integrationLogs
 * @param options Request options.
 */
export function getTeamIntegrationLogs(options) {
    const { connectionId: instanceId, headers, app_id, change_type, count, page, service_id, user, userId } = options;
    const queryParams = { app_id, change_type, count, page, service_id, user };
    const customParams = { userId };
    return httpGet(instanceId, constructUrl(`/api/team.integrationLogs`, queryParams), headers, customParams);
}
