import { User } from "../types/user";
/**
 * Find a user with an email address.
 * Documentation: https://api.slack.com/methods/users.lookupByEmail
 * @param options Request options.
 */
export declare function getUserByEmail(options: User.GetUserByEmail.Options.RawApi): Promise<import("@avst-api/commons").Response<User.GetUserByEmail.Response.OK | User.GetUserByEmail.Response.Error>>;
/**
 * Lists all users in a Slack team.
 * Documentation: https://api.slack.com/methods/users.list
 * @param options Request options.
 */
export declare function getUsers(options: User.GetUsers.Options.RawApi): Promise<import("@avst-api/commons").Response<User.GetUsers.Response.OK | User.GetUsers.Response.Error>>;
/**
 * Gets information about a user.
 * Documentation: https://api.slack.com/methods/users.info
 * @param options Request options.
 */
export declare function getUserInfo(options: User.GetInfo.Options.RawApi): Promise<import("@avst-api/commons").Response<User.GetInfo.Response.OK | User.GetInfo.Response.Error>>;
/**
 * Get a user's identity.
 * Documentation: https://api.slack.com/methods/users.identity
 * @param options Request options.
 */
export declare function getUserIdentity(options: User.GetIdentity.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
 * List conversations the calling user may access.
 * Documentation: https://api.slack.com/methods/users.conversations
 * @param options Request options.
 */
export declare function getUserConversations(options: User.GetConversations.Options.RawApi): Promise<import("@avst-api/commons").Response<User.GetConversations.Response.OK | User.GetConversations.Response.Error>>;
/**
 * Gets user presence information.
 * Documentation: https://api.slack.com/methods/users.getPresence
 * @param options Request options.
 */
export declare function getUserPresence(options: User.GetPresence.Options.RawApi): Promise<import("@avst-api/commons").Response<User.GetPresence.Response.OK | User.GetPresence.Response.Error>>;
/**
 * Manually sets user presence.
 * Documentation: https://api.slack.com/methods/users.setPresence
 * @param options Request options.
 */
export declare function setUserPresence(options: User.SetPresence.Options.RawApi): Promise<import("@avst-api/commons").Response<User.SetPresence.Response.OK | User.SetPresence.Response.Error>>;
//# sourceMappingURL=user.d.ts.map