import { httpGet } from "../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpPost } from "../raw-api/common";
/**
 * Find a user with an email address.
 * Documentation: https://api.slack.com/methods/users.lookupByEmail
 * @param options Request options.
 */
export function getUserByEmail(options) {
    const { connectionId: instanceId, headers, email, preferredAuth, userId } = options;
    const queryParams = { email };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/users.lookupByEmail`, queryParams), headers, customParams);
}
/**
 * Lists all users in a Slack team.
 * Documentation: https://api.slack.com/methods/users.list
 * @param options Request options.
 */
export function getUsers(options) {
    const { connectionId: instanceId, headers, limit, cursor, include_locale, team_id, preferredAuth, userId } = options;
    const queryParams = { limit, cursor, include_locale, team_id };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/users.list`, queryParams), headers, customParams);
}
/**
 * Gets information about a user.
 * Documentation: https://api.slack.com/methods/users.info
 * @param options Request options.
 */
export function getUserInfo(options) {
    const { connectionId: instanceId, headers, include_locale, user, preferredAuth, userId } = options;
    const queryParams = { include_locale, user };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/users.info`, queryParams), headers, customParams);
}
/**
 * Get a user's identity.
 * Documentation: https://api.slack.com/methods/users.identity
 * @param options Request options.
 */
export function getUserIdentity(options) {
    const { connectionId: instanceId, headers, userId } = options;
    const customParams = { userId };
    return httpGet(instanceId, `/api/users.identity`, headers, customParams);
}
/**
 * List conversations the calling user may access.
 * Documentation: https://api.slack.com/methods/users.conversations
 * @param options Request options.
 */
export function getUserConversations(options) {
    const { connectionId: instanceId, headers, user, types, exclude_archived, limit, cursor, team_id, preferredAuth, userId } = options;
    const queryParams = { user, types, exclude_archived, limit, cursor, team_id };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/users.conversations`, queryParams), headers, customParams);
}
/**
 * Gets user presence information.
 * Documentation: https://api.slack.com/methods/users.getPresence
 * @param options Request options.
 */
export function getUserPresence(options) {
    const { connectionId: instanceId, headers, user, preferredAuth, userId } = options;
    const queryParams = { user };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/users.getPresence`, queryParams), headers, customParams);
}
/**
 * Manually sets user presence.
 * Documentation: https://api.slack.com/methods/users.setPresence
 * @param options Request options.
 */
export function setUserPresence(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/users.setPresence`, body, headers, customParams);
}
