import { httpPost } from "../raw-api/common";
import { httpGet } from "../raw-api/common";
import { constructUrl } from "@avst-api/commons";
/**
 * Create a User Group
 * Documentation: https://api.slack.com/methods/usergroups.create
 * @param options Request options.
 */
export function createUserGroup(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/usergroups.create`, body, headers, customParams);
}
/**
 * Disable an existing User Group
 * Documentation: https://api.slack.com/methods/usergroups.disable
 * @param options Request options.
 */
export function disableUserGroup(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/usergroups.disable`, body, headers, customParams);
}
/**
 * Enable a User Group
 * Documentation: https://api.slack.com/methods/usergroups.enable
 * @param options Request options.
 */
export function enableUserGroup(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/usergroups.enable`, body, headers, customParams);
}
/**
 * List all User Groups for a team
 * Documentation: https://api.slack.com/methods/usergroups.list
 * @param options Request options.
 */
export function getUserGroups(options) {
    const { connectionId: instanceId, headers, include_users, include_count, include_disabled, preferredAuth, userId } = options;
    const queryParams = { include_users, include_count, include_disabled };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/usergroups.list`, queryParams), headers, customParams);
}
/**
 * Update an existing User Group
 * Documentation: https://api.slack.com/methods/usergroups.update
 * @param options Request options.
 */
export function updateUserGroup(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/usergroups.update`, body, headers, customParams);
}
