import { httpPost } from "../raw-api/common";
import { constructUrl } from "@avst-api/commons";
/**
 * Update an existing view.
 * Documentation: https://api.slack.com/methods/views.update
 * @param options Request options.
 */
export function updateView(options) {
    const { connectionId: instanceId, headers, view_id, external_id, view, hash, preferredAuth, userId } = options;
    const queryParams = { view_id, external_id, view, hash };
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, constructUrl(`/api/views.update`, queryParams), undefined, headers, customParams);
}
/**
 * Push a view onto the stack of a root view.
 * Documentation: https://api.slack.com/methods/views.push
 * @param options Request options.
 */
export function pushView(options) {
    const { connectionId: instanceId, headers, trigger_id, view, preferredAuth, userId } = options;
    const queryParams = { trigger_id, view };
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, constructUrl(`/api/views.push`, queryParams), undefined, headers, customParams);
}
/**
 * Publish a static view for a User.
 * Documentation: https://api.slack.com/methods/views.publish
 * @param options Request options.
 */
export function publishView(options) {
    const { connectionId: instanceId, headers, user_id, view, hash } = options;
    const queryParams = { user_id, view, hash };
    return httpPost(instanceId, constructUrl(`/api/views.publish`, queryParams), undefined, headers);
}
/**
 * Open a view for a user.
 * Documentation: https://api.slack.com/methods/views.open
 * @param options Request options.
 */
export function openView(options) {
    const { connectionId: instanceId, headers, trigger_id, view, preferredAuth, userId } = options;
    const queryParams = { trigger_id, view };
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, constructUrl(`/api/views.open`, queryParams), undefined, headers, customParams);
}
