import { defs_ok_true } from "../definitions/defs_ok_true";
import { defs_ok_false } from "../definitions/defs_ok_false";
import { UserIdOption } from "../common";
import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
export declare namespace Admin {
    namespace Users {
        namespace SetRegular {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * The ID (`T1234`) of the workspace.
                 */
                team_id: string;
                /**
                 * The ID of the user to designate as a regular user.
                 */
                user_id: string;
            };
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    [x: string]: any;
                };
                type Error = {
                    ok: defs_ok_false;
                    [x: string]: any;
                };
            }
            namespace Options {
                interface Base extends UserIdOption {
                    body: Admin.Users.SetRegular.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace SetOwner {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * The ID (`T1234`) of the workspace.
                 */
                team_id: string;
                /**
                 * Id of the user to promote to owner.
                 */
                user_id: string;
            };
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    [x: string]: any;
                };
                type Error = {
                    ok: defs_ok_false;
                    [x: string]: any;
                };
            }
            namespace Options {
                interface Base extends UserIdOption {
                    body: Admin.Users.SetOwner.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace SetExpiration {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * The ID (`T1234`) of the workspace.
                 */
                team_id: string;
                /**
                 * The ID of the user to set an expiration for.
                 */
                user_id: string;
                /**
                 * Timestamp when guest account should be disabled.
                 */
                expiration_ts: number;
            };
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    [x: string]: any;
                };
                type Error = {
                    ok: defs_ok_false;
                    [x: string]: any;
                };
            }
            namespace Options {
                interface Base extends UserIdOption {
                    body: Admin.Users.SetExpiration.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace SetAdmin {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * The ID (`T1234`) of the workspace.
                 */
                team_id: string;
                /**
                 * The ID of the user to designate as an admin.
                 */
                user_id: string;
            };
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    [x: string]: any;
                };
                type Error = {
                    ok: defs_ok_false;
                    [x: string]: any;
                };
            }
            namespace Options {
                interface Base extends UserIdOption {
                    body: Admin.Users.SetAdmin.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace RemoveUser {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * The ID (`T1234`) of the workspace.
                 */
                team_id: string;
                /**
                 * The ID of the user to remove.
                 */
                user_id: string;
            };
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    [x: string]: any;
                };
                type Error = {
                    ok: defs_ok_false;
                    [x: string]: any;
                };
            }
            namespace Options {
                interface Base extends UserIdOption {
                    body: Admin.Users.RemoveUser.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetUsers {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    [x: string]: any;
                };
                type Error = {
                    ok: defs_ok_false;
                    [x: string]: any;
                };
            }
            namespace Options {
                interface Base extends UserIdOption {
                    /**
                     * The ID (`T1234`) of the workspace.
                     */
                    team_id: string;
                    /**
                     * Set `cursor` to `next_cursor` returned by the previous call to list items in the next page.
                     */
                    cursor?: string;
                    /**
                     * Limit for how many users to be retrieved per page
                     */
                    limit?: number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace InviteUser {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * The ID (`T1234`) of the workspace.
                 */
                team_id: string;
                /**
                 * The email address of the person to invite.
                 */
                email: string;
                /**
                 * A comma-separated list of `channel_id`s for this user to join. At least one channel is required.
                 */
                channel_ids: string;
                /**
                 * An optional message to send to the user in the invite email.
                 */
                custom_message?: string;
                /**
                 * Full name of the user.
                 */
                real_name?: string;
                /**
                 * Allow this invite to be resent in the future if a user has not signed up yet. (default: false)
                 */
                resend?: boolean;
                /**
                 * Is this user a multi-channel guest user? (default: false)
                 */
                is_restricted?: boolean;
                /**
                 * Is this user a single channel guest user? (default: false)
                 */
                is_ultra_restricted?: boolean;
                /**
                 * Timestamp when guest account should be disabled. Only include this timestamp if you are inviting a guest user and you want their account to expire on a certain date.
                 */
                guest_expiration_ts?: string;
                /**
                 * Allow invited user to sign in via email and password. Only available for Enterprise Grid teams via admin invite.
                 */
                email_password_policy_enabled?: boolean;
            };
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    [x: string]: any;
                };
                type Error = {
                    ok: defs_ok_false;
                    [x: string]: any;
                };
            }
            namespace Options {
                interface Base extends UserIdOption {
                    body: Admin.Users.InviteUser.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace AssignUser {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * The ID (`T1234`) of the workspace.
                 */
                team_id: string;
                /**
                 * The ID of the user to add to the workspace.
                 */
                user_id: string;
                /**
                 * True if user should be added to the workspace as a guest.
                 */
                is_restricted?: boolean;
                /**
                 * True if user should be added to the workspace as a single-channel guest.
                 */
                is_ultra_restricted?: boolean;
                /**
                 * Comma separated values of channel IDs to add user in the new workspace.
                 */
                channel_ids?: string;
            };
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    [x: string]: any;
                };
                type Error = {
                    ok: defs_ok_false;
                    [x: string]: any;
                };
            }
            namespace Options {
                interface Base extends UserIdOption {
                    body: Admin.Users.AssignUser.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
}
//# sourceMappingURL=admin.d.ts.map