import { defs_channel } from "../definitions/defs_channel";
import { defs_ok_true } from "../definitions/defs_ok_true";
import { defs_ts } from "../definitions/defs_ts";
import { defs_ok_false } from "../definitions/defs_ok_false";
import { PreferredAuthOption } from "../common";
import { UserIdOption } from "../common";
import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
import { objs_message } from "../definitions/objs_message";
import { defs_bot_id } from "../definitions/defs_bot_id";
import { defs_user_id } from "../definitions/defs_user_id";
import { defs_team } from "../definitions/defs_team";
import { defs_app_id } from "../definitions/defs_app_id";
import { defs_channel_id } from "../definitions/defs_channel_id";
export declare namespace Chat {
    namespace DeleteMessage {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Timestamp of the message to be deleted.
             */
            ts: string;
            /**
             * Channel containing the message to be deleted.
             */
            channel: string;
            /**
             * Pass true to delete the message as the authed user with `chat:write:user` scope. [Bot users](/bot-users) in this context are considered authed users. If unused or false, the message will be deleted with `chat:write:bot` scope.
             */
            as_user?: boolean;
        };
        namespace Response {
            type OK = {
                channel: defs_channel;
                ok: defs_ok_true;
                ts: defs_ts;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "message_not_found" | "channel_not_found" | "cant_delete_message" | "compliance_exports_prevent_deletion" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Chat.DeleteMessage.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace DeleteScheduledMessage {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Pass true to delete the message as the authed user with `chat:write:user` scope. [Bot users](/bot-users) in this context are considered authed users. If unused or false, the message will be deleted with `chat:write:bot` scope.
             */
            as_user?: boolean;
            /**
             * The channel the scheduled_message is posting to
             */
            channel: string;
            /**
             * `scheduled_message_id` returned from call to chat.scheduleMessage
             */
            scheduled_message_id: string;
        };
        namespace Response {
            type OK = {
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "invalid_scheduled_message_id" | "channel_not_found" | "bad_token" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "ekm_access_denied" | "missing_scope" | "invalid_arguments" | "invalid_arg_name" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Chat.DeleteScheduledMessage.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetPermalink {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                channel: defs_channel;
                ok: defs_ok_true;
                permalink: string;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "channel_not_found" | "message_not_found" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * The ID of the conversation or channel containing the message
                 */
                channel: string;
                /**
                 * A message's `ts` value, uniquely identifying it within a channel
                 */
                message_ts: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace PostMeMessage {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Channel to send message to. Can be a public channel, private group or IM channel. Can be an encoded ID, or a name.
             */
            channel: string;
            /**
             * Text of the message to send.
             */
            text: string;
        };
        namespace Response {
            type OK = {
                channel?: defs_channel;
                ok: defs_ok_true;
                ts?: defs_ts;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "channel_not_found" | "not_in_channel" | "is_archived" | "msg_too_long" | "no_text" | "rate_limited" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Chat.PostMeMessage.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace PostEphemeralMessage {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Pass true to post the message as the authed user. Defaults to true if the chat:write:bot scope is not included. Otherwise, defaults to false.
             */
            as_user?: boolean;
            /**
             * A JSON-based array of structured attachments, presented as a URL-encoded string.
             */
            attachments: string;
            /**
             * A JSON-based array of structured blocks, presented as a URL-encoded string.
             */
            blocks?: string;
            /**
             * Channel, private group, or IM channel to send message to. Can be an encoded ID, or a name.
             */
            channel: string;
            /**
             * Emoji to use as the icon for this message. Overrides `icon_url`. Must be used in conjunction with `as_user` set to `false`, otherwise ignored. See [authorship](#authorship) below.
             */
            icon_emoji?: string;
            /**
             * URL to an image to use as the icon for this message. Must be used in conjunction with `as_user` set to false, otherwise ignored. See [authorship](#authorship) below.
             */
            icon_url?: string;
            /**
             * Find and link channel names and usernames.
             */
            link_names?: boolean;
            /**
             * Change how messages are treated. Defaults to `none`. See [below](#formatting).
             */
            parse?: string;
            /**
             * How this field works and whether it is required depends on other fields you use in your API call. [See below](#text_usage) for more detail.
             */
            text: string;
            /**
             * Provide another message's `ts` value to post this message in a thread. Avoid using a reply's `ts` value; use its parent's value instead. Ephemeral messages in threads are only shown if there is already an active thread.
             */
            thread_ts?: string;
            /**
             * `id` of the user who will receive the ephemeral message. The user should be in the channel specified by the `channel` argument.
             */
            user?: string;
            /**
             * Set your bot's user name. Must be used in conjunction with `as_user` set to false, otherwise ignored. See [authorship](#authorship) below.
             */
            username?: string;
        };
        namespace Response {
            type OK = {
                message_ts: defs_ts;
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "channel_not_found" | "is_archived" | "msg_too_long" | "no_text" | "restricted_action" | "too_many_attachments" | "user_not_in_channel" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Chat.PostEphemeralMessage.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace PostMessage {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Pass true to post the message as the authed user, instead of as a bot. Defaults to false. See [authorship](#authorship) below.
             */
            as_user?: string;
            /**
             * A JSON-based array of structured attachments, presented as a URL-encoded string.
             */
            attachments?: string;
            /**
             * A JSON-based array of structured blocks, presented as a URL-encoded string.
             */
            blocks?: string;
            /**
             * Channel, private group, or IM channel to send message to. Can be an encoded ID, or a name. See [below](#channels) for more details.
             */
            channel: string;
            /**
             * Emoji to use as the icon for this message. Overrides `icon_url`. Must be used in conjunction with `as_user` set to `false`, otherwise ignored. See [authorship](#authorship) below.
             */
            icon_emoji?: string;
            /**
             * URL to an image to use as the icon for this message. Must be used in conjunction with `as_user` set to false, otherwise ignored. See [authorship](#authorship) below.
             */
            icon_url?: string;
            /**
             * Find and link channel names and usernames.
             */
            link_names?: boolean;
            /**
             * Disable Slack markup parsing by setting to `false`. Enabled by default.
             */
            mrkdwn?: boolean;
            /**
             * Change how messages are treated. Defaults to `none`. See [below](#formatting).
             */
            parse?: string;
            /**
             * Used in conjunction with `thread_ts` and indicates whether reply should be made visible to everyone in the channel or conversation. Defaults to `false`.
             */
            reply_broadcast?: boolean;
            /**
             * How this field works and whether it is required depends on other fields you use in your API call. [See below](#text_usage) for more detail.
             */
            text?: string;
            /**
             * Provide another message's `ts` value to make this message a reply. Avoid using a reply's `ts` value; use its parent instead.
             */
            thread_ts?: string;
            /**
             * Pass true to enable unfurling of primarily text-based content.
             */
            unfurl_links?: boolean;
            /**
             * Pass false to disable unfurling of media content.
             */
            unfurl_media?: boolean;
            /**
             * Set your bot's user name. Must be used in conjunction with `as_user` set to false, otherwise ignored. See [authorship](#authorship) below.
             */
            username?: string;
        };
        namespace Response {
            type OK = {
                channel: defs_channel;
                message: objs_message;
                ok: defs_ok_true;
                ts: defs_ts;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "channel_not_found" | "not_in_channel" | "is_archived" | "msg_too_long" | "no_text" | "too_many_attachments" | "rate_limited" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Chat.PostMessage.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace ScheduleMessage {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Provide another message's `ts` value to make this message a reply. Avoid using a reply's `ts` value; use its parent instead.
             */
            thread_ts?: string;
            /**
             * A JSON-based array of structured blocks, presented as a URL-encoded string.
             */
            blocks?: string;
            /**
             * A JSON-based array of structured attachments, presented as a URL-encoded string.
             */
            attachments?: string;
            /**
             * Pass true to enable unfurling of primarily text-based content.
             */
            unfurl_links?: boolean;
            /**
             * Text of the message to send. See below for an explanation of [formatting](#formatting). This field is usually required, unless you're providing only `attachments` instead. Provide no more than 40,000 characters or [risk truncation](/changelog/2018-04-truncating-really-long-messages).
             */
            text?: string;
            /**
             * Find and link channel names and usernames.
             */
            link_names?: boolean;
            /**
             * Pass false to disable unfurling of media content.
             */
            unfurl_media?: boolean;
            /**
             * Change how messages are treated. Defaults to `none`. See [below](#formatting).
             */
            parse?: string;
            /**
             * Pass true to post the message as the authed user, instead of as a bot. Defaults to false. See [authorship](#authorship) below.
             */
            as_user?: boolean;
            /**
             * Unix EPOCH timestamp of time in future to send the message.
             */
            post_at: string;
            /**
             * Channel, private group, or DM channel to send message to. Can be an encoded ID, or a name. See [below](#channels) for more details.
             */
            channel: string;
            /**
             * Used in conjunction with `thread_ts` and indicates whether reply should be made visible to everyone in the channel or conversation. Defaults to `false`.
             */
            reply_broadcast?: boolean;
        };
        namespace Response {
            type OK = {
                channel: defs_channel;
                message: {
                    bot_id: defs_bot_id;
                    text: string;
                    type: string;
                    user: defs_user_id;
                    team?: defs_team;
                    thread_ts?: string;
                    bot_profile?: {
                        id?: defs_bot_id;
                        deleted?: boolean;
                        name?: string;
                        updated?: number;
                        app_id?: defs_app_id;
                        icons?: {
                            image_36?: string;
                            image_48?: string;
                            image_72?: string;
                        };
                        team_id?: defs_team;
                    };
                    attachments?: Array<{
                        text?: string;
                        pretext?: string;
                        fallback?: string;
                        id?: number;
                    }>;
                };
                ok: defs_ok_true;
                post_at: number;
                scheduled_message_id: string;
            };
            type Error = {
                error: "invalid_time" | "time_in_past" | "time_too_far" | "channel_not_found" | "not_in_channel" | "is_archived" | "msg_too_long" | "no_text" | "restricted_action" | "restricted_action_read_only_channel" | "restricted_action_thread_only_channel" | "restricted_action_non_threadable_channel" | "too_many_attachments" | "rate_limited" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "ekm_access_denied" | "missing_scope" | "invalid_arguments" | "invalid_arg_name" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Chat.ScheduleMessage.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace ScheduledMessage {
        namespace GetScheduledMessages {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    response_metadata: {
                        next_cursor: string;
                    };
                    scheduled_messages: Array<{
                        channel_id: defs_channel_id;
                        date_created: number;
                        id: string;
                        post_at: number;
                        text?: string;
                    }>;
                };
                type Error = {
                    /**
                     * Note: PHP callstack is only visible in dev/qa
                     */
                    callstack?: string;
                    error: "invalid_channel" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "ekm_access_denied" | "missing_scope" | "invalid_arguments" | "invalid_arg_name" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                    ok: defs_ok_false;
                };
            }
            namespace Options {
                interface Base extends PreferredAuthOption, UserIdOption {
                    /**
                     * The channel of the scheduled messages
                     */
                    channel?: string;
                    /**
                     * A UNIX timestamp of the latest value in the time range
                     */
                    latest?: number;
                    /**
                     * A UNIX timestamp of the oldest value in the time range
                     */
                    oldest?: number;
                    /**
                     * Maximum number of original entries to return.
                     */
                    limit?: number;
                    /**
                     * For pagination purposes, this is the `cursor` value returned from a previous call to `chat.scheduledmessages.list` indicating where you want to start this call from.
                     */
                    cursor?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace UnfurlMessage {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Channel ID of the message
             */
            channel: string;
            /**
             * Timestamp of the message to add unfurl behavior to.
             */
            ts: string;
            /**
             * URL-encoded JSON map with keys set to URLs featured in the the message, pointing to their unfurl blocks or message attachments.
             */
            unfurls: string;
            /**
             * Provide a simply-formatted string to send as an ephemeral message to the user as invitation to authenticate further and enable full unfurling behavior
             */
            user_auth_message?: string;
            /**
             * Set to `true` or `1` to indicate the user must install your Slack app to trigger unfurls for this domain
             */
            user_auth_required?: boolean;
            /**
             * Send users to this custom URL where they will complete authentication in your app to fully trigger unfurling. Value should be properly URL-encoded.
             */
            user_auth_url?: string;
        };
        namespace Response {
            type OK = {
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "cannot_unfurl_url" | "cannot_find_service" | "missing_unfurls" | "cannot_prompt" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Chat.UnfurlMessage.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace UpdateMessage {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Pass true to update the message as the authed user. [Bot users](/bot-users) in this context are considered authed users.
             */
            as_user?: string;
            /**
             * A JSON-based array of structured attachments, presented as a URL-encoded string. This field is required when not presenting `text`. If you don't include this field, the message's previous `attachments` will be retained. To remove previous `attachments`, include an empty array for this field.
             */
            attachments?: string;
            /**
             * A JSON-based array of [structured blocks](/block-kit/building), presented as a URL-encoded string. If you don't include this field, the message's previous `blocks` will be retained. To remove previous `blocks`, include an empty array for this field.
             */
            blocks?: string;
            /**
             * Channel containing the message to be updated.
             */
            channel: string;
            /**
             * Find and link channel names and usernames. Defaults to `none`. If you do not specify a value for this field, the original value set for the message will be overwritten with the default, `none`.
             */
            link_names?: string;
            /**
             * Change how messages are treated. Defaults to `client`, unlike `chat.postMessage`. Accepts either `none` or `full`. If you do not specify a value for this field, the original value set for the message will be overwritten with the default, `client`.
             */
            parse?: string;
            /**
             * New text for the message, using the [default formatting rules](/reference/surfaces/formatting). It's not required when presenting `blocks` or `attachments`.
             */
            text?: string;
            /**
             * Timestamp of the message to be updated.
             */
            ts: string;
        };
        namespace Response {
            type OK = {
                channel: string;
                message: {
                    attachments?: Array<any>;
                    blocks?: any;
                    text: string;
                };
                ok: defs_ok_true;
                text: string;
                ts: string;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "message_not_found" | "cant_update_message" | "channel_not_found" | "edit_window_closed" | "msg_too_long" | "too_many_attachments" | "rate_limited" | "no_text" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "request_timeout" | "invalid_json" | "json_not_object" | "upgrade_required" | "fatal_error" | "is_inactive";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Chat.UpdateMessage.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
}
//# sourceMappingURL=chat.d.ts.map