import { defs_ok_true } from "../definitions/defs_ok_true";
import { defs_ok_false } from "../definitions/defs_ok_false";
import { PreferredAuthOption } from "../common";
import { UserIdOption } from "../common";
import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
import { objs_conversation } from "../definitions/objs_conversation";
import { objs_message } from "../definitions/objs_message";
import { defs_user_id } from "../definitions/defs_user_id";
import { defs_ts } from "../definitions/defs_ts";
import { defs_dm_id } from "../definitions/defs_dm_id";
import { defs_team } from "../definitions/defs_team";
import { objs_user_profile_short } from "../definitions/objs_user_profile_short";
import { objs_response_metadata } from "../definitions/objs_response_metadata";
export declare namespace Conversation {
    namespace ArchiveConversation {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * ID of conversation to archive
             */
            channel: string;
        };
        namespace Response {
            type OK = {
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "method_not_supported_for_channel_type" | "missing_scope" | "not_supported" | "channel_not_found" | "already_archived" | "cant_archive_general" | "restricted_action" | "not_authed" | "invalid_auth" | "account_inactive" | "user_is_bot" | "user_is_restricted" | "user_is_ultra_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "team_added_to_org" | "missing_charset" | "superfluous_charset";
                needed?: string;
                ok: defs_ok_false;
                provided?: string;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Conversation.ArchiveConversation.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace CloseConversation {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Conversation to close.
             */
            channel: string;
        };
        namespace Response {
            type OK = {
                already_closed?: boolean;
                no_op?: boolean;
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "method_not_supported_for_channel_type" | "channel_not_found" | "user_does_not_own_channel" | "missing_scope" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                needed?: string;
                ok: defs_ok_false;
                provided?: string;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Conversation.CloseConversation.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace CreateConversation {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Name of the public or private channel to create
             */
            name: string;
            /**
             * Create a private channel instead of a public one
             */
            is_private?: boolean;
        };
        namespace Response {
            type OK = {
                channel: objs_conversation;
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                detail?: string;
                error: "method_not_supported_for_channel_type" | "missing_scope" | "name_taken" | "restricted_action" | "no_channel" | "invalid_name_required" | "invalid_name_punctuation" | "invalid_name_maxlength" | "invalid_name_specials" | "invalid_name" | "not_authed" | "invalid_auth" | "account_inactive" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                needed?: string;
                ok: defs_ok_false;
                provided?: string;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Conversation.CreateConversation.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetHistory {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                channel_actions_count: number;
                channel_actions_ts: number | null;
                has_more: boolean;
                messages: Array<objs_message>;
                ok: defs_ok_true;
                pin_count: number;
                latest?: string;
                oldest?: string;
            };
            type Error = {
                callstack?: string;
                error: "missing_scope" | "channel_not_found" | "invalid_ts_latest" | "invalid_ts_oldest" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                needed?: string;
                ok: defs_ok_false;
                provided?: string;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * Conversation ID to fetch history for.
                 */
                channel: string;
                /**
                 * End of time range of messages to include in results.
                 */
                latest?: number;
                /**
                 * Start of time range of messages to include in results.
                 */
                oldest?: number;
                /**
                 * Include messages with latest or oldest timestamp in results only when either timestamp is specified.
                 */
                inclusive?: boolean;
                /**
                 * The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the users list hasn't been reached.
                 */
                limit?: number;
                /**
                 * Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first "page" of the collection. See [pagination](/docs/pagination) for more detail.
                 */
                cursor?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetInfo {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                channel: objs_conversation;
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "missing_scope" | "channel_not_found" | "team_added_to_org" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                needed?: string;
                ok: defs_ok_false;
                provided?: string;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * Conversation ID to learn more about
                 */
                channel: string;
                /**
                 * Set this to `true` to receive the locale for this conversation. Defaults to `false`
                 */
                include_locale?: boolean;
                /**
                 * Set to `true` to include the member count for the specified conversation. Defaults to `false`
                 */
                include_num_members?: boolean;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace InviteUser {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * The ID of the public or private channel to invite user(s) to.
             */
            channel: string;
            /**
             * A comma separated list of user IDs. Up to 1000 users may be listed.
             */
            users: string;
        };
        namespace Response {
            type OK = {
                channel: objs_conversation;
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error?: "method_not_supported_for_channel_type" | "missing_scope" | "channel_not_found" | "user_not_found" | "no_user" | "cant_invite_self" | "not_in_channel" | "already_in_channel" | "is_archived" | "cant_invite" | "too_many_users" | "ura_max_channels" | "not_authed" | "invalid_auth" | "account_inactive" | "user_is_bot" | "user_is_restricted" | "user_is_ultra_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "team_added_to_org" | "missing_charset" | "superfluous_charset";
                errors?: Array<{
                    error: "method_not_supported_for_channel_type" | "missing_scope" | "channel_not_found" | "user_not_found" | "no_user" | "cant_invite_self" | "not_in_channel" | "already_in_channel" | "is_archived" | "cant_invite" | "too_many_users" | "ura_max_channels" | "not_authed" | "invalid_auth" | "account_inactive" | "user_is_bot" | "user_is_restricted" | "user_is_ultra_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "team_added_to_org" | "missing_charset" | "superfluous_charset";
                    ok: defs_ok_false;
                    user?: defs_user_id;
                }>;
                needed?: string;
                ok: defs_ok_false;
                provided?: string;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Conversation.InviteUser.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace JoinConversation {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * ID of conversation to join
             */
            channel: string;
        };
        namespace Response {
            type OK = {
                channel: objs_conversation;
                ok: defs_ok_true;
                response_metadata?: {
                    warnings?: Array<string>;
                };
                warning?: string;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "method_not_supported_for_channel_type" | "missing_scope" | "channel_not_found" | "is_archived" | "not_authed" | "invalid_auth" | "account_inactive" | "user_is_bot" | "user_is_restricted" | "user_is_ultra_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "team_added_to_org" | "missing_charset" | "superfluous_charset";
                needed?: string;
                ok: defs_ok_false;
                provided?: string;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Conversation.JoinConversation.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace KickUser {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * ID of conversation to remove user from.
             */
            channel: string;
            /**
             * User ID to be removed.
             */
            user: string;
        };
        namespace Response {
            type OK = {
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "method_not_supported_for_channel_type" | "missing_scope" | "channel_not_found" | "user_not_found" | "cant_kick_self" | "not_in_channel" | "cant_kick_from_general" | "restricted_action" | "not_authed" | "invalid_auth" | "account_inactive" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                needed?: string;
                ok: defs_ok_false;
                provided?: string;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Conversation.KickUser.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace LeaveConversation {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Conversation to leave
             */
            channel: string;
        };
        namespace Response {
            type OK = {
                not_in_channel?: true;
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "method_not_supported_for_channel_type" | "last_member" | "missing_scope" | "channel_not_found" | "is_archived" | "cant_leave_general" | "not_authed" | "invalid_auth" | "account_inactive" | "user_is_bot" | "user_is_restricted" | "user_is_ultra_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "team_added_to_org" | "missing_charset" | "superfluous_charset";
                needed?: string;
                ok: defs_ok_false;
                provided?: string;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Conversation.LeaveConversation.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetConversations {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                channels: Array<objs_conversation>;
                ok: defs_ok_true;
                response_metadata?: {
                    next_cursor: string;
                };
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "missing_scope" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                needed?: string;
                ok: defs_ok_false;
                provided?: string;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * Set to `true` to exclude archived channels from the list
                 */
                exclude_archived?: boolean;
                /**
                 * Mix and match channel types by providing a comma-separated list of any combination of `public_channel`, `private_channel`, `mpim`, `im`
                 */
                types?: string;
                /**
                 * The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn't been reached. Must be an integer no larger than 1000.
                 */
                limit?: number;
                /**
                 * Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first "page" of the collection. See [pagination](/docs/pagination) for more detail.
                 */
                cursor?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetMembers {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                members: Array<defs_user_id>;
                ok: defs_ok_true;
                response_metadata: {
                    next_cursor: string;
                };
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "channel_not_found" | "invalid_limit" | "invalid_cursor" | "fetch_members_failed" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * ID of the conversation to retrieve members for
                 */
                channel: string;
                /**
                 * The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the users list hasn't been reached.
                 */
                limit?: number;
                /**
                 * Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first "page" of the collection. See [pagination](/docs/pagination) for more detail.
                 */
                cursor?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace OpenConversation {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Resume a conversation by supplying an `im` or `mpim`'s ID. Or provide the `users` field instead.
             */
            channel?: string;
            /**
             * Comma separated lists of users. If only one user is included, this creates a 1:1 DM.  The ordering of the users is preserved whenever a multi-person direct message is returned. Supply a `channel` when not supplying `users`.
             */
            users?: string;
            /**
             * Boolean, indicates you want the full IM channel definition in the response.
             */
            return_im?: boolean;
        };
        namespace Response {
            type OK = {
                already_open?: boolean;
                channel: objs_conversation & {
                    created?: string;
                    id: defs_dm_id;
                    is_im?: boolean;
                    last_read?: defs_ts;
                    latest?: objs_message;
                    unread_count?: number;
                    unread_count_display?: number;
                    user?: defs_user_id;
                };
                no_op?: boolean;
                ok: defs_ok_true;
            };
            type Error = {
                callstack?: string;
                error: "method_not_supported_for_channel_type" | "user_not_found" | "user_not_visible" | "user_disabled" | "users_list_not_supplied" | "not_enough_users" | "too_many_users" | "invalid_user_combination" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "channel_not_found";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Conversation.OpenConversation.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace RenameConversation {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * ID of conversation to rename
             */
            channel: string;
            /**
             * New name for conversation.
             */
            name: string;
        };
        namespace Response {
            type OK = {
                channel: objs_conversation;
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "user_is_restricted" | "method_not_supported_for_channel_type" | "missing_scope" | "channel_not_found" | "not_in_channel" | "not_authorized" | "invalid_name" | "name_taken" | "invalid_name_required" | "invalid_name_punctuation" | "invalid_name_maxlength" | "invalid_name_specials" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                needed?: string;
                ok: defs_ok_false;
                provided?: string;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Conversation.RenameConversation.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetReplies {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                has_more?: boolean;
                messages: Array<{
                    last_read?: defs_ts;
                    latest_reply?: defs_ts;
                    reply_count: number;
                    reply_users?: Array<defs_user_id>;
                    reply_users_count?: number;
                    source_team?: defs_team;
                    subscribed: boolean;
                    team?: defs_team;
                    text: string;
                    thread_ts: defs_ts;
                    ts: defs_ts;
                    type: string;
                    unread_count?: number;
                    user: defs_user_id;
                    user_profile?: objs_user_profile_short;
                    user_team?: defs_team;
                } & {
                    is_starred?: boolean;
                    parent_user_id: defs_user_id;
                    source_team?: defs_team;
                    team?: defs_team;
                    text: string;
                    thread_ts: defs_ts;
                    ts: defs_ts;
                    type: string;
                    user: defs_user_id;
                    user_profile?: objs_user_profile_short;
                    user_team?: defs_team;
                }>;
                ok: defs_ok_true;
                response_metadata?: objs_response_metadata;
            };
            type Error = {
                callstack?: string;
                error: "missing_scope" | "channel_not_found" | "thread_not_found" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                needed?: string;
                ok: defs_ok_false;
                provided?: string;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * Include messages with latest or oldest timestamp in results only when either timestamp is specified.
                 */
                inclusive?: boolean;
                /**
                 * Unique identifier of a thread's parent message. ts must be the timestamp of an existing message with 0 or more replies. If there are no replies then just the single message referenced by ts will return - it is just an ordinary, unthreaded message.
                 */
                ts: string;
                /**
                 * Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first "page" of the collection. See [pagination](/docs/pagination) for more detail.
                 */
                cursor?: string;
                /**
                 * The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the users list hasn't been reached.
                 */
                limit?: number;
                /**
                 * Start of time range of messages to include in results.
                 */
                oldest?: number;
                /**
                 * Conversation ID to fetch thread from.
                 */
                channel: string;
                /**
                 * End of time range of messages to include in results.
                 */
                latest?: number;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace SetPurpose {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Conversation to set the purpose of
             */
            channel: string;
            /**
             * A new, specialer purpose
             */
            purpose: string;
        };
        namespace Response {
            type OK = {
                channel: objs_conversation;
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "method_not_supported_for_channel_type" | "missing_scope" | "channel_not_found" | "not_in_channel" | "is_archived" | "too_long" | "user_is_restricted" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                needed?: string;
                ok: defs_ok_false;
                provided?: string;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Conversation.SetPurpose.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace SetTopic {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Conversation to set the topic of
             */
            channel: string;
            /**
             * The new topic string. Does not support formatting or linkification.
             */
            topic: string;
        };
        namespace Response {
            type OK = {
                channel: objs_conversation;
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "method_not_supported_for_channel_type" | "missing_scope" | "channel_not_found" | "not_in_channel" | "is_archived" | "too_long" | "user_is_restricted" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                needed?: string;
                ok: defs_ok_false;
                provided?: string;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Conversation.SetTopic.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace UnarchiveConversation {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * ID of conversation to unarchive
             */
            channel: string;
        };
        namespace Response {
            type OK = {
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "method_not_supported_for_channel_type" | "missing_scope" | "channel_not_found" | "not_archived" | "not_authed" | "invalid_auth" | "account_inactive" | "user_is_bot" | "user_is_restricted" | "user_is_ultra_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "team_added_to_org" | "missing_charset" | "superfluous_charset";
                needed?: string;
                ok: defs_ok_false;
                provided?: string;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Conversation.UnarchiveConversation.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
}
//# sourceMappingURL=conversation.d.ts.map