import { defs_ok_true } from "../definitions/defs_ok_true";
import { defs_ok_false } from "../definitions/defs_ok_false";
import { PreferredAuthOption } from "../common";
import { UserIdOption } from "../common";
import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
import { defs_user_id } from "../definitions/defs_user_id";
import { objs_paging } from "../definitions/objs_paging";
import { objs_file } from "../definitions/objs_file";
import { objs_comments } from "../definitions/objs_comments";
import { objs_response_metadata } from "../definitions/objs_response_metadata";
export declare namespace File {
    namespace Comment {
        namespace DeleteComment {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * File to delete a comment from.
                 */
                file: string;
                /**
                 * The comment to delete.
                 */
                id: string;
            };
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                };
                type Error = {
                    /**
                     * Note: PHP callstack is only visible in dev/qa
                     */
                    callstack?: string;
                    error: "cant_delete" | "comment_not_found" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                    ok: defs_ok_false;
                };
            }
            namespace Options {
                interface Base extends PreferredAuthOption, UserIdOption {
                    body: File.Comment.DeleteComment.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace DeleteFile {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * ID of file to delete.
             */
            file: string;
        };
        namespace Response {
            type OK = {
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "file_not_found" | "file_deleted" | "cant_delete_file" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: File.DeleteFile.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetInfo {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                comments: objs_comments;
                content_highlight_html: string;
                content_highlight_css: string;
                editor?: defs_user_id;
                is_truncated: boolean;
                content: string;
                file: objs_file;
                ok: defs_ok_true;
                paging?: objs_paging;
                response_metadata?: objs_response_metadata;
            };
            type Error = {
                error: "file_not_found" | "file_deleted" | "timezone_count_failed" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * Number of items to return per page.
                 */
                count?: string;
                /**
                 * Parameter for pagination. File comments are paginated for a single file. Set `cursor` equal to the `next_cursor` attribute returned by the previous request's `response_metadata`. This parameter is optional, but pagination is mandatory: the default value simply fetches the first "page" of the collection of comments. See [pagination](/docs/pagination) for more details.
                 */
                cursor?: string;
                /**
                 * The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn't been reached.
                 */
                limit?: number;
                /**
                 * Specify a file by providing its ID.
                 */
                file: string;
                /**
                 * Page number of results to return.
                 */
                page?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetFiles {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                files: Array<objs_file>;
                ok: defs_ok_true;
                paging: objs_paging;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "user_not_found" | "unknown_type" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * Filter files created by a single user.
                 */
                user?: string;
                /**
                 * Filter files appearing in a specific channel, indicated by its ID.
                 */
                channel?: string;
                /**
                 * Filter files created after this timestamp (inclusive).
                 */
                ts_from?: number;
                /**
                 * Filter files created before this timestamp (inclusive).
                 */
                ts_to?: number;
                /**
                 * Filter files by type ([see below](#file_types)). You can pass multiple values in the types argument, like `types=spaces,snippets`.The default value is `all`, which does not filter the list.
                 */
                types?: string;
                count?: string;
                page?: string;
                /**
                 * Show truncated file info for files hidden due to being too old, and the team who owns the file being over the file limit.
                 */
                show_files_hidden_by_limit?: boolean;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace PublicUrl {
        namespace RevokePublicUrl {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * File to revoke
                 */
                file: string;
            };
            namespace Response {
                type OK = {
                    file: objs_file;
                    ok: defs_ok_true;
                };
                type Error = {
                    /**
                     * Note: PHP callstack is only visible in dev/qa
                     */
                    callstack?: string;
                    error: "file_not_found" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                    ok: defs_ok_false;
                };
            }
            namespace Options {
                interface Base extends UserIdOption {
                    body: File.PublicUrl.RevokePublicUrl.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace CreatePublicUrl {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * File to share
                 */
                file: string;
            };
            namespace Response {
                type OK = {
                    file: objs_file;
                    ok: defs_ok_true;
                };
                type Error = {
                    /**
                     * Note: PHP callstack is only visible in dev/qa
                     */
                    callstack?: string;
                    error: "file_not_found" | "not_allowed" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                    ok: defs_ok_false;
                };
            }
            namespace Options {
                interface Base extends UserIdOption {
                    body: File.PublicUrl.CreatePublicUrl.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace UploadFile {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Comma-separated list of channel names or IDs where the file will be shared.
             */
            channels?: string;
            /**
             * Title of file.
             */
            title?: string;
            /**
             * The message text introducing the file in specified `channels`.
             */
            initial_comment?: string;
            /**
             * A [file type](/types/file#file_types) identifier.
             */
            filetype?: string;
            /**
             * Filename of file.
             */
            filename?: string;
            /**
             * File contents via a POST variable. If omitting this parameter, you must provide a `file`.
             */
            content?: string;
            /**
             * File contents via `multipart/form-data`. If omitting this parameter, you must submit `content`.
             */
            file?: ArrayBuffer | string;
            /**
             * Provide another message's `ts` value to upload this file as a reply. Never use a reply's `ts` value; use its parent instead.
             */
            thread_ts?: number;
        };
        namespace Response {
            type OK = {
                file: objs_file;
                ok: defs_ok_true;
            };
            type Error = {
                callstack?: string;
                error: "posting_to_general_channel_denied" | "invalid_channel" | "file_uploads_disabled" | "file_uploads_except_images_disabled" | "storage_limit_reached" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: File.UploadFile.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace Remote {
        namespace AddFile {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    file?: objs_file;
                    [x: string]: any;
                };
                type Error = {
                    ok: defs_ok_false;
                    [x: string]: any;
                };
            }
            namespace Options {
                interface Base {
                    /**
                     * Creator defined GUID for the file.
                     */
                    external_id: string;
                    /**
                     * Title of the file being shared.
                     */
                    title: string;
                    /**
                     * type of file
                     */
                    filetype?: string;
                    /**
                     * URL of the remote file.
                     */
                    external_url: string;
                    /**
                     * Preview of the document via `multipart/form-data`.
                     */
                    preview_image?: string;
                    /**
                     * A text file (txt, pdf, doc, etc.) containing textual search terms that are used to improve discovery of the remote file.
                     */
                    indexable_file_contents?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetInfo {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    [x: string]: any;
                };
                type Error = {
                    ok: defs_ok_false;
                    [x: string]: any;
                };
            }
            namespace Options {
                interface Base extends PreferredAuthOption, UserIdOption {
                    /**
                     * Specify a file by providing its ID.
                     */
                    file?: string;
                    /**
                     * Creator defined GUID for the file.
                     */
                    external_id?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetFiles {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    [x: string]: any;
                };
                type Error = {
                    ok: defs_ok_false;
                    [x: string]: any;
                };
            }
            namespace Options {
                interface Base extends PreferredAuthOption, UserIdOption {
                    /**
                     * Filter files appearing in a specific channel, indicated by its ID.
                     */
                    channel?: string;
                    /**
                     * Filter files created after this timestamp (inclusive).
                     */
                    ts_from?: number;
                    /**
                     * Filter files created before this timestamp (inclusive).
                     */
                    ts_to?: number;
                    /**
                     * The maximum number of items to return.
                     */
                    limit?: number;
                    /**
                     * Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first "page" of the collection. See [pagination](/docs/pagination) for more detail.
                     */
                    cursor?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace RemoveFile {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    [x: string]: any;
                };
                type Error = {
                    ok: defs_ok_false;
                    [x: string]: any;
                };
            }
            namespace Options {
                interface Base {
                    /**
                     * Specify a file by providing its ID.
                     */
                    file?: string;
                    /**
                     * Creator defined GUID for the file.
                     */
                    external_id?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace ShareFile {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    [x: string]: any;
                };
                type Error = {
                    ok: defs_ok_false;
                    [x: string]: any;
                };
            }
            namespace Options {
                interface Base extends PreferredAuthOption, UserIdOption {
                    /**
                     * Specify a file registered with Slack by providing its ID. Either this field or `external_id` or both are required.
                     */
                    file?: string;
                    /**
                     * The globally unique identifier (GUID) for the file, as set by the app registering the file with Slack.  Either this field or `file` or both are required.
                     */
                    external_id?: string;
                    /**
                     * Comma-separated list of channel IDs where the file will be shared.
                     */
                    channels?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace UpdateFile {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    [x: string]: any;
                };
                type Error = {
                    ok: defs_ok_false;
                    [x: string]: any;
                };
            }
            namespace Options {
                interface Base {
                    /**
                     * Specify a file by providing its ID.
                     */
                    file?: string;
                    /**
                     * Creator defined GUID for the file.
                     */
                    external_id?: string;
                    /**
                     * Title of the file being shared.
                     */
                    title?: string;
                    /**
                     * type of file
                     */
                    filetype?: string;
                    /**
                     * URL of the remote file.
                     */
                    external_url?: string;
                    /**
                     * Preview of the document via `multipart/form-data`.
                     */
                    preview_image?: string;
                    /**
                     * File containing contents that can be used to improve searchability for the remote file.
                     */
                    indexable_file_contents?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
}
//# sourceMappingURL=file.d.ts.map