import { defs_ok_true } from "../definitions/defs_ok_true";
import { defs_ok_false } from "../definitions/defs_ok_false";
import { PreferredAuthOption } from "../common";
import { UserIdOption } from "../common";
import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
export declare namespace Pins {
    namespace RemovePin {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Channel where the item is pinned to.
             */
            channel: string;
            /**
             * Timestamp of the message to un-pin.
             */
            timestamp?: string;
        };
        namespace Response {
            type OK = {
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "bad_timestamp" | "file_not_found" | "file_comment_not_found" | "message_not_found" | "no_item_specified" | "not_pinned" | "permission_denied" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_typ" | "missing_post_typ" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeou" | "upgrade_required";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Pins.RemovePin.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetPins {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = any;
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "channel_not_found" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * Channel to get pinned items for.
                 */
                channel: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace AddPin {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Channel to pin the item in.
             */
            channel: string;
            /**
             * Timestamp of the message to pin.
             */
            timestamp?: string;
        };
        namespace Response {
            type OK = {
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "bad_timestamp" | "message_not_found" | "channel_not_found" | "no_item_specified" | "already_pinned" | "permission_denied" | "file_not_shared" | "not_pinnable" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Pins.AddPin.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
}
//# sourceMappingURL=pins.d.ts.map