import { defs_ok_true } from "../definitions/defs_ok_true";
import { defs_ok_false } from "../definitions/defs_ok_false";
import { PreferredAuthOption } from "../common";
import { UserIdOption } from "../common";
import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
import { defs_channel } from "../definitions/defs_channel";
import { objs_message } from "../definitions/objs_message";
import { objs_file } from "../definitions/objs_file";
import { objs_comment } from "../definitions/objs_comment";
import { objs_paging } from "../definitions/objs_paging";
import { objs_response_metadata } from "../definitions/objs_response_metadata";
export declare namespace Reaction {
    namespace AddReaction {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Channel where the message to add reaction to was posted.
             */
            channel: string;
            /**
             * Reaction (emoji) name.
             */
            name: string;
            /**
             * Timestamp of the message to add reaction to.
             */
            timestamp: string;
        };
        namespace Response {
            type OK = {
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "bad_timestamp" | "message_not_found" | "no_item_specified" | "invalid_name" | "already_reacted" | "too_many_emoji" | "too_many_reactions" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Reaction.AddReaction.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetReaction {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                ok: defs_ok_true;
                type: "file";
                file: objs_file;
            } | {
                ok: defs_ok_true;
                type: "message";
                message: objs_message;
                channel: defs_channel;
            } | {
                ok: defs_ok_true;
                comment: objs_comment;
                file: objs_file;
                type: "file_comment";
            };
            type Error = {
                callstack?: string;
                error: "bad_timestamp" | "file_not_found" | "file_comment_not_found" | "message_not_found" | "no_item_specified" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * If true always return the complete reaction list.
                 */
                full?: boolean;
                /**
                 * File comment to get reactions for.
                 */
                file_comment?: string;
                /**
                 * Timestamp of the message to get reactions for.
                 */
                timestamp?: string;
                /**
                 * File to get reactions for.
                 */
                file?: string;
                /**
                 * Channel where the message to get reactions for was posted.
                 */
                channel?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetReactions {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                items: Array<{
                    channel: defs_channel;
                    message: objs_message;
                    type: "message";
                } | {
                    file: objs_file;
                    type: "file";
                } | {
                    comment: objs_comment;
                    file: objs_file;
                    type: "file_comment";
                }>;
                ok: defs_ok_true;
                paging?: objs_paging;
                response_metadata?: objs_response_metadata;
            };
            type Error = {
                callstack?: string;
                error: "bad_timestamp" | "file_not_found" | "file_comment_not_found" | "message_not_found" | "no_item_specified" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * Number of items to return per page.
                 */
                count?: string;
                /**
                 * If true always return the complete reaction list.
                 */
                full?: boolean;
                /**
                 * Parameter for pagination. Set `cursor` equal to the `next_cursor` attribute returned by the previous request's `response_metadata`. This parameter is optional, but pagination is mandatory: the default value simply fetches the first "page" of the collection. See [pagination](/docs/pagination) for more details.
                 */
                cursor?: string;
                /**
                 * The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn't been reached.
                 */
                limit?: number;
                /**
                 * Show reactions made by this user. Defaults to the authed user.
                 */
                user?: string;
                /**
                 * Page number of results to return.
                 */
                page?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace RemoveReaction {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Reaction (emoji) name.
             */
            name: string;
            /**
             * File to remove reaction from.
             */
            file?: string;
            /**
             * File comment to remove reaction from.
             */
            file_comment?: string;
            /**
             * Channel where the message to remove reaction from was posted.
             */
            channel?: string;
            /**
             * Timestamp of the message to remove reaction from.
             */
            timestamp?: string;
        };
        namespace Response {
            type OK = {
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "bad_timestamp" | "file_not_found" | "file_comment_not_found" | "message_not_found" | "no_item_specified" | "invalid_name" | "no_reaction" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: Reaction.RemoveReaction.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
}
//# sourceMappingURL=reaction.d.ts.map