import { defs_ok_true } from "../definitions/defs_ok_true";
import { objs_paging } from "../definitions/objs_paging";
import { objs_message } from "../definitions/objs_message";
import { UserIdOption } from "../common";
import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
export declare namespace Search {
    namespace SearchMessages {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                ok: defs_ok_true;
                query: string;
                messages?: {
                    total?: number;
                    pagination?: {
                        total_count?: number;
                        page?: number;
                        per_page?: number;
                        page_count?: number;
                        first?: number;
                        last?: number;
                    };
                    paging?: objs_paging;
                    matches?: Array<objs_message>;
                };
            };
            type Error = {
                error: "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_true;
                response_metadata?: {
                    messages?: Array<string>;
                };
            };
        }
        namespace Options {
            interface Base extends UserIdOption {
                /**
                 * Change sort direction to ascending (`asc`) or descending (`desc`).
                 */
                sort_dir?: "asc" | "desc";
                /**
                 * Search query.
                 */
                query: string;
                /**
                 * Return matches sorted by either `score` or `timestamp`.
                 */
                sort?: "score" | "timestamp";
                /**
                 * Number of items to return per page.
                 */
                count?: number;
                /**
                 * Pass a value of `true` to enable query highlight markers (see below).
                 */
                highlight?: boolean;
                /**
                 * Page number of results to return.
                 */
                page?: number;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
}
//# sourceMappingURL=search.d.ts.map