import { defs_user_id } from "../definitions/defs_user_id";
import { defs_ok_true } from "../definitions/defs_ok_true";
import { objs_paging } from "../definitions/objs_paging";
import { defs_ok_false } from "../definitions/defs_ok_false";
import { UserIdOption } from "../common";
import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
import { objs_team } from "../definitions/objs_team";
import { PreferredAuthOption } from "../common";
import { defs_app_id } from "../definitions/defs_app_id";
import { defs_channel } from "../definitions/defs_channel";
import { objs_team_profile_field } from "../definitions/objs_team_profile_field";
export declare namespace Team {
    namespace GetAccessLogs {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                logins: Array<{
                    count: number;
                    country: string;
                    date_first: number;
                    date_last: number;
                    ip: string;
                    isp: string;
                    region: string;
                    user_agent: string;
                    user_id: defs_user_id;
                    username: string;
                }>;
                ok: defs_ok_true;
                paging: objs_paging;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "paid_only" | "over_pagination_limit" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends UserIdOption {
                /**
                 * Number of items to return per page.
                 */
                count?: number;
                /**
                 * Page number of results to return.
                 */
                page?: number;
                /**
                 * End of time range of logs to include in results (inclusive).
                 */
                before?: number;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetBillableInfo {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                billable_info: {
                    [x: string]: {
                        billing_active: boolean;
                    };
                };
                ok: defs_ok_true;
            };
            type Error = {
                error: "user_not_found" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends UserIdOption {
                /**
                 * A user to retrieve the billable information for. Defaults to all users.
                 */
                user?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetInfo {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                ok: defs_ok_true;
                team: objs_team;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * Team to get info on, if omitted, will return information about the current team. Will only return team that the authenticated token is allowed to see through external shared channels
                 */
                team?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetIntegrationLogs {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                logs: Array<{
                    admin_app_id?: defs_app_id;
                    app_id: defs_app_id;
                    app_type: string;
                    change_type: string;
                    channel?: defs_channel;
                    date: string;
                    scope: string;
                    service_id?: string;
                    service_type?: string;
                    user_id: defs_user_id;
                    user_name: string;
                }>;
                ok: defs_ok_true;
                paging: objs_paging;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends UserIdOption {
                /**
                 * Filter logs to this Slack app. Defaults to all logs.
                 */
                app_id?: string;
                /**
                 * Filter logs with this change type. Defaults to all logs.
                 */
                change_type?: string;
                count?: string;
                page?: string;
                /**
                 * Filter logs to this service. Defaults to all logs.
                 */
                service_id?: string;
                /**
                 * Filter logs generated by this user’s actions. Defaults to all logs.
                 */
                user?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace Profile {
        namespace GetProfile {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    profile: {
                        fields: Array<objs_team_profile_field>;
                    };
                };
                type Error = {
                    /**
                     * Note: PHP callstack is only visible in dev/qa
                     */
                    callstack?: string;
                    error: "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_typ" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeou" | "upgrade_required";
                    ok: defs_ok_false;
                };
            }
            namespace Options {
                interface Base extends PreferredAuthOption, UserIdOption {
                    /**
                     * Filter by visibility.
                     */
                    visibility?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
}
//# sourceMappingURL=team.d.ts.map