import { defs_ok_true } from "../definitions/defs_ok_true";
import { objs_user_profile } from "../definitions/objs_user_profile";
import { defs_ok_false } from "../definitions/defs_ok_false";
import { UserIdOption } from "../common";
import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
import { PreferredAuthOption } from "../common";
import { objs_user } from "../definitions/objs_user";
import { objs_response_metadata } from "../definitions/objs_response_metadata";
import { objs_conversation } from "../definitions/objs_conversation";
export declare namespace User {
    namespace Profile {
        namespace SetProfile {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * Name of a single key to set. Usable only if `profile` is not passed.
                 */
                name?: string;
                /**
                 * Collection of key:value pairs presented as a URL-encoded JSON hash. At most 50 fields may be set. Each field name is limited to 255 characters.
                 */
                profile?: string;
                /**
                 * ID of user to change. This argument may only be specified by team admins on paid teams.
                 */
                user?: string;
                /**
                 * Value to set a single key to. Usable only if `profile` is not passed.
                 */
                value?: string;
            };
            namespace Response {
                type OK = {
                    email_pending?: string;
                    ok: defs_ok_true;
                    profile: objs_user_profile;
                    username: string;
                };
                type Error = {
                    /**
                     * Note: PHP callstack is only visible in dev/qa
                     */
                    callstack?: string;
                    error: "reserved_name" | "invalid_profile" | "profile_set_failed" | "not_admin" | "not_app_admin" | "cannot_update_admin_user" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                    ok: defs_ok_false;
                };
            }
            namespace Options {
                interface Base extends UserIdOption {
                    body: User.Profile.SetProfile.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetProfile {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    profile: objs_user_profile;
                };
                type Error = {
                    /**
                     * Note: PHP callstack is only visible in dev/qa
                     */
                    callstack?: string;
                    error: "user_not_found" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                    ok: defs_ok_false;
                };
            }
            namespace Options {
                interface Base extends PreferredAuthOption, UserIdOption {
                    /**
                     * Include labels for each ID in custom profile fields
                     */
                    include_labels?: boolean;
                    /**
                     * User to retrieve profile info for
                     */
                    user?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace GetUserByEmail {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                ok: defs_ok_true;
                user: objs_user;
                [x: string]: any;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "users_not_found" | "enterprise_is_restricted" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * An email address belonging to a user in the workspace
                 */
                email: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetUsers {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                cache_ts: number;
                members: Array<objs_user>;
                ok: defs_ok_true;
                response_metadata?: objs_response_metadata;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "limit_required" | "invalid_cursor" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the users list hasn't been reached. Providing no `limit` value will result in Slack attempting to deliver you the entire result set. If the collection is too large you may experience `limit_required` or HTTP 500 errors.
                 */
                limit?: number;
                /**
                 * Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first "page" of the collection. See [pagination](/docs/pagination) for more detail.
                 */
                cursor?: string;
                /**
                 * Set this to `true` to receive the locale for users. Defaults to `false`
                 */
                include_locale?: boolean;
                /**
                 * Encoded team id to list users in, required if org token is used
                 */
                team_id?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetInfo {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                ok: defs_ok_true;
                user: objs_user;
                [x: string]: any;
            };
            type Error = {
                callstack?: string;
                error: "user_not_found" | "user_not_visible" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * Set this to `true` to receive the locale for this user. Defaults to `false`
                 */
                include_locale?: boolean;
                /**
                 * User to get info on
                 */
                user: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetIdentity {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = any;
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends UserIdOption {
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetConversations {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                channels: Array<objs_conversation>;
                ok: defs_ok_true;
                response_metadata?: {
                    next_cursor: string;
                };
                [x: string]: any;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "method_not_supported_for_channel_type" | "missing_scope" | "invalid_types" | "invalid_cursor" | "invalid_limit" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * Browse conversations by a specific user ID's membership. Non-public channels are restricted to those where the calling user shares membership.
                 */
                user?: string;
                /**
                 * Mix and match channel types by providing a comma-separated list of any combination of `public_channel`, `private_channel`, `mpim`, `im`
                 */
                types?: string;
                /**
                 * Set to `true` to exclude archived channels from the list
                 */
                exclude_archived?: boolean;
                /**
                 * The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn't been reached. Must be an integer no larger than 1000.
                 */
                limit?: number;
                /**
                 * Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first "page" of the collection. See [pagination](/docs/pagination) for more detail.
                 */
                cursor?: string;
                /**
                 * Encoded team id to list conversations in, required if org token is used
                 */
                team_id?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetPresence {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                auto_away?: boolean;
                connection_count?: number;
                last_activity?: number;
                manual_away?: boolean;
                ok: defs_ok_true;
                online?: boolean;
                presence: string;
                [x: string]: any;
            };
            type Error = {
                error: string;
                ok: defs_ok_false;
                [x: string]: any;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * User to get presence info on. Defaults to the authed user.
                 */
                user?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace SetPresence {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Either `auto` or `away`
             */
            presence: string;
        };
        namespace Response {
            type OK = {
                ok: defs_ok_true;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "invalid_presence" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: User.SetPresence.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
}
//# sourceMappingURL=user.d.ts.map