import { defs_ok_true } from "../definitions/defs_ok_true";
import { objs_subteam } from "../definitions/objs_subteam";
import { defs_ok_false } from "../definitions/defs_ok_false";
import { PreferredAuthOption } from "../common";
import { UserIdOption } from "../common";
import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
import { defs_user_id } from "../definitions/defs_user_id";
export declare namespace UserGroup {
    namespace CreateUserGroup {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * A comma separated string of encoded channel IDs for which the User Group uses as a default.
             */
            channels?: string;
            /**
             * A short description of the User Group.
             */
            description?: string;
            /**
             * A mention handle. Must be unique among channels, users and User Groups.
             */
            handle?: string;
            /**
             * Include the number of users in each User Group.
             */
            include_count?: boolean;
            /**
             * A name for the User Group. Must be unique among User Groups.
             */
            name: string;
        };
        namespace Response {
            type OK = {
                ok: defs_ok_true;
                usergroup: objs_subteam;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "permission_denied" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: UserGroup.CreateUserGroup.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace DisableUserGroup {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Include the number of users in the User Group.
             */
            include_count?: boolean;
            /**
             * The encoded ID of the User Group to disable.
             */
            usergroup: string;
        };
        namespace Response {
            type OK = {
                ok: defs_ok_true;
                usergroup: objs_subteam;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "permission_denied" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: UserGroup.DisableUserGroup.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace EnableUserGroup {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Include the number of users in the User Group.
             */
            include_count?: boolean;
            /**
             * The encoded ID of the User Group to enable.
             */
            usergroup: string;
        };
        namespace Response {
            type OK = {
                ok: defs_ok_true;
                usergroup: objs_subteam;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_require" | "fatal_error" | "missing_charset" | "superfluous_charset";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: UserGroup.EnableUserGroup.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetUserGroups {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                ok: defs_ok_true;
                usergroups: Array<objs_subteam>;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_require" | "fatal_error" | "missing_charset" | "superfluous_charset";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * Include the list of users for each User Group.
                 */
                include_users?: boolean;
                /**
                 * Include the number of users in each User Group.
                 */
                include_count?: boolean;
                /**
                 * Include disabled User Groups.
                 */
                include_disabled?: boolean;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace UpdateUserGroup {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * A mention handle. Must be unique among channels, users and User Groups.
             */
            handle?: string;
            /**
             * A short description of the User Group.
             */
            description?: string;
            /**
             * A comma separated string of encoded channel IDs for which the User Group uses as a default.
             */
            channels?: string;
            /**
             * Include the number of users in the User Group.
             */
            include_count?: boolean;
            /**
             * The encoded ID of the User Group to update.
             */
            usergroup: string;
            /**
             * A name for the User Group. Must be unique among User Groups.
             */
            name?: string;
        };
        namespace Response {
            type OK = {
                ok: defs_ok_true;
                usergroup: objs_subteam;
            };
            type Error = {
                /**
                 * Note: PHP callstack is only visible in dev/qa
                 */
                callstack?: string;
                error: "permission_denied" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_require" | "fatal_error" | "missing_charset" | "superfluous_charset";
                ok: defs_ok_false;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                body: UserGroup.UpdateUserGroup.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace User {
        namespace GetUsers {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    users: Array<defs_user_id>;
                };
                type Error = {
                    /**
                     * Note: PHP callstack is only visible in dev/qa
                     */
                    callstack?: string;
                    error: "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_require" | "fatal_error" | "missing_charset" | "superfluous_charset";
                    ok: defs_ok_false;
                };
            }
            namespace Options {
                interface Base extends PreferredAuthOption, UserIdOption {
                    /**
                     * Allow results that involve disabled User Groups.
                     */
                    include_disabled?: boolean;
                    /**
                     * The encoded ID of the User Group to update.
                     */
                    usergroup: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace UpdateUsers {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * Include the number of users in the User Group.
                 */
                include_count?: boolean;
                /**
                 * The encoded ID of the User Group to update.
                 */
                usergroup: string;
                /**
                 * A comma separated string of encoded user IDs that represent the entire list of users for the User Group.
                 */
                users: string;
            };
            namespace Response {
                type OK = {
                    ok: defs_ok_true;
                    usergroup: objs_subteam;
                };
                type Error = {
                    /**
                     * Note: PHP callstack is only visible in dev/qa
                     */
                    callstack?: string;
                    error: "permission_denied" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_require" | "fatal_error" | "missing_charset" | "superfluous_charset";
                    ok: defs_ok_false;
                };
            }
            namespace Options {
                interface Base extends PreferredAuthOption, UserIdOption {
                    body: UserGroup.User.UpdateUsers.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
}
//# sourceMappingURL=userGroup.d.ts.map