import { defs_ok_true } from "../definitions/defs_ok_true";
import { defs_ok_false } from "../definitions/defs_ok_false";
import { objs_view_home_tab, objs_view_response, objs_view_modal } from "../definitions/objs_view";
import { PreferredAuthOption } from "../common";
import { UserIdOption } from "../common";
import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
export declare namespace View {
    namespace UpdateView {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                ok: defs_ok_true;
                view: objs_view_response;
            };
            type Error = {
                ok: defs_ok_false;
                [key: string]: any;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * A [view payload](/reference/surfaces/views). This must be a JSON-encoded string.
                 */
                view: objs_view_modal;
                /**
                 * A unique identifier of the view set by the developer. Must be unique for all views on a team. Max length of 255 characters. Either view_id or external_id is required.
                 */
                external_id?: string;
                /**
                 * A string that represents view state to protect against possible race conditions.
                 */
                hash?: string;
                /**
                 * A unique identifier of the view to be updated. Either view_id or external_id is required.
                 */
                view_id?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace PushView {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                ok: defs_ok_true;
                view: objs_view_response;
            };
            type Error = {
                ok: defs_ok_false;
                [key: string]: any;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * Exchange a trigger to post to the user.
                 */
                trigger_id: string;
                /**
                 * A [view payload](/reference/surfaces/views). This must be a JSON-encoded string.
                 */
                view: objs_view_modal;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace PublishView {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                ok: defs_ok_true;
                view: objs_view_response;
            };
            type Error = {
                ok: defs_ok_false;
                [key: string]: any;
            };
        }
        namespace Options {
            interface Base {
                /**
                 * id of the user you want publish a view to.
                 */
                user_id: string;
                /**
                 * A [view payload](/reference/surfaces/views). This must be a JSON-encoded string.
                 */
                view: objs_view_home_tab;
                /**
                 * A string that represents view state to protect against possible race conditions.
                 */
                hash?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace OpenView {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                ok: defs_ok_true;
                view: objs_view_response;
            };
            type Error = {
                ok: defs_ok_false;
                [key: string]: any;
            };
        }
        namespace Options {
            interface Base extends PreferredAuthOption, UserIdOption {
                /**
                 * Exchange a trigger to post to the user.
                 */
                trigger_id: string;
                /**
                 * A [view payload](/reference/surfaces/views). This must be a JSON-encoded string.
                 */
                view: objs_view_modal;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
}
//# sourceMappingURL=view.d.ts.map